tic;    
[VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction();
toc;

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = mainFunction()
    % This is the "main function".  In Matlab, things work best if you rename this function to match the filename.
   [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel();
end

function [algebraicVariableCount] = getAlgebraicVariableCount()
    % Used later when setting a global variable with the number of algebraic variables.
    % Note: This is not the "main method".
    algebraicVariableCount =495;
end
% There are a total of 99 entries in each of the rate and state variable arrays.
% There are a total of 272 entries in the constant variable array.
%

function [VOI, STATES, ALGEBRAIC, CONSTANTS] = solveModel()

    [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends();
    % Create ALGEBRAIC of correct size
    global algebraicVariableCount;  algebraicVariableCount = getAlgebraicVariableCount();
    % Initialise constants and state variables
    [INIT_STATES, CONSTANTS] = initConsts;

    % Set timespan to solve over
    tspan = [0, 5.6];

    % Set numerical accuracy options for ODE solver
    options = odeset('RelTol', 1e-06, 'AbsTol', 1e-06, 'MaxStep', 1e-4);

    % Solve model with ODE solver
    [VOI, STATES] = ode15s(@(VOI, STATES)computeRates(VOI, STATES, CONSTANTS), tspan, INIT_STATES, options);

    % Compute algebraic variables
    [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS);
    ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI);

    labels = {'I_stim in component environment (fA)',...
                'V_mem in component environment (volt)', ... 
                'x_Cai in component environment (fmol)', ...
                'x_Nai in component environment (fmol)',...
                'x_Ki in component environment (fmol)',...
                'q_mem in component environment (fC)'};
        
    [~, i_st, i_alg] = find_indices(labels, cellstr(LEGEND_CONSTANTS), cellstr(LEGEND_STATES), cellstr(LEGEND_ALGEBRAIC));
    plot_selected(i_st,VOI,STATES,LEGEND_VOI,LEGEND_STATES,'modular',ceil(sqrt(length(i_st))))
    plot_selected(i_alg,VOI,ALGEBRAIC,LEGEND_VOI,LEGEND_ALGEBRAIC,'modular',ceil(sqrt(length(i_alg))))

    % currents
    labels = {'v_Na in component Na_channel (fmol_per_sec)',...
            'v_K1 in component K1_channel (fmol_per_sec)',...
            'v_K in component K_channel (fmol_per_sec)',...
            'v_Kp in component Kp_channel (fmol_per_sec)',...
            'v_Ca1 in component LCC (fmol_per_sec)',...
            'v_Ca2 in component LCC (fmol_per_sec)',...
            'v_K1 in component LCC (fmol_per_sec)',...
            'v_K2 in component LCC (fmol_per_sec)'};
    if true
        [~, i_st, i_alg] = find_indices(labels, cellstr(LEGEND_CONSTANTS), cellstr(LEGEND_STATES), cellstr(LEGEND_ALGEBRAIC));
        plot_selected(i_st,VOI,STATES,LEGEND_VOI,LEGEND_STATES,'Currents',ceil(sqrt(length(i_st))))
        plot_selected(i_alg,VOI,ALGEBRAIC,LEGEND_VOI,LEGEND_ALGEBRAIC,'currents',ceil(sqrt(length(i_alg))))
    end
    
    % debugging I_mem and components of I_K1
    labels = {'I_mem in component K1_channel (fA)',...
                'v_Ke in component K1_channel (fmol_per_sec)',...
                'v_Ki in component K1_channel (fmol_per_sec)',...
                'v_C_K1 in component K1_channel (fmol_per_sec)',...
                'v_O_K1 in component K1_channel (fmol_per_sec)'};
        
    if false
        [~, i_st, i_alg] = find_indices(labels, cellstr(LEGEND_CONSTANTS), cellstr(LEGEND_STATES), cellstr(LEGEND_ALGEBRAIC));
        plot_selected(i_st,VOI,STATES,LEGEND_VOI,LEGEND_STATES,'debug',ceil(sqrt(length(i_st))))
        plot_selected(i_alg,VOI,ALGEBRAIC,LEGEND_VOI,LEGEND_ALGEBRAIC,'debug',ceil(sqrt(length(i_alg))))
    end
end

function [i_con, i_st, i_alg] = find_indices(labels, LEGEND_CONSTANTS, LEGEND_STATES, LEGEND_ALGEBRAIC)
% return the indices for the selected labels
    all_legends = [LEGEND_CONSTANTS; LEGEND_STATES; LEGEND_ALGEBRAIC];
    
    i_con = [];
    for i = 1:length(labels)
        i_con = [i_con; find(strcmp(labels{i},LEGEND_CONSTANTS))];
    end
    i_st = [];
    for i = 1:length(labels)
        i_st = [i_st; find(strcmp(labels{i},LEGEND_STATES))];
    end
    i_alg = [];
    for i = 1:length(labels)
        i_alg = [i_alg; find(strcmp(labels{i},LEGEND_ALGEBRAIC))];
    end
    
    if length(i_con) + length(i_st) + length(i_alg) < length(labels)
        warning('missing index');
    end
end

function [] = plot_selected(ids,x,y,legend_x,legend_y,titlestr,ns)
    istart = 30;
    istart = find(x > 5e0, 1);
    figure();
%     plot stimuli
    for i = 1:length(ids)
        subplot(ns,ns,i)
        plot(x(istart:end), y(istart:end,ids(i)));
        xlabel('time (s)');
        str = split(legend_y(ids(i),:), ' ');
        str = legend_y(ids(i),:);
        l = legend(str);
        set(l,'interpreter','none');
    end
    suptitle(titlestr)    
end

function [LEGEND_STATES, LEGEND_ALGEBRAIC, LEGEND_VOI, LEGEND_CONSTANTS] = createLegends()
    LEGEND_STATES = ''; LEGEND_ALGEBRAIC = ''; LEGEND_VOI = ''; LEGEND_CONSTANTS = '';
    LEGEND_CONSTANTS(:,1) = strpad('K_000_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,2) = strpad('K_000_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,3) = strpad('K_001_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,4) = strpad('K_001_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,5) = strpad('K_00_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,6) = strpad('K_010_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,7) = strpad('K_010_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,8) = strpad('K_011_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,9) = strpad('K_011_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,10) = strpad('K_01_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,11) = strpad('K_020_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,12) = strpad('K_021_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,13) = strpad('K_100_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,14) = strpad('K_100_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,15) = strpad('K_101_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,16) = strpad('K_101_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,17) = strpad('K_10_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,18) = strpad('K_10_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,19) = strpad('K_110_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,20) = strpad('K_110_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,21) = strpad('K_111_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,22) = strpad('K_111_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,23) = strpad('K_11_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,24) = strpad('K_11_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,25) = strpad('K_120_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,26) = strpad('K_121_LCC in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,27) = strpad('K_12_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,28) = strpad('K_13_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,29) = strpad('K_14_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,30) = strpad('K_15_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,31) = strpad('K_1_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,32) = strpad('K_1_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,33) = strpad('K_200_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,34) = strpad('K_201_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,35) = strpad('K_20_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,36) = strpad('K_210_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,37) = strpad('K_211_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,38) = strpad('K_21_K in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,39) = strpad('K_2_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,40) = strpad('K_2_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,41) = strpad('K_300_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,42) = strpad('K_301_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,43) = strpad('K_310_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,44) = strpad('K_311_Na in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,45) = strpad('K_3_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,46) = strpad('K_3_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,47) = strpad('K_4_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,48) = strpad('K_4_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,49) = strpad('K_5_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,50) = strpad('K_5_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,51) = strpad('K_6_NCX in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,52) = strpad('K_6_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,53) = strpad('K_7_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,54) = strpad('K_8_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,55) = strpad('K_9_NaK in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,56) = strpad('K_CMDN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,57) = strpad('K_CMDNCa in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,58) = strpad('K_C_K1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,59) = strpad('K_C_Kp in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,60) = strpad('K_Cae in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,61) = strpad('K_Cai in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,62) = strpad('K_H in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,63) = strpad('K_Ke in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,64) = strpad('K_Ki in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,65) = strpad('K_MgADP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,66) = strpad('K_MgATP in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,67) = strpad('K_Nae in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,68) = strpad('K_Nai in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,69) = strpad('K_O_K1 in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,70) = strpad('K_O_Kp in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,71) = strpad('K_P_i in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,72) = strpad('K_TRPN in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,73) = strpad('K_TRPNCa in component BG_parameters (per_fmol)');
    LEGEND_CONSTANTS(:,74) = strpad('kappa_10_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,75) = strpad('kappa_11_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,76) = strpad('kappa_12_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,77) = strpad('kappa_13_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,78) = strpad('kappa_14_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,79) = strpad('kappa_15_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,80) = strpad('kappa_1_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,81) = strpad('kappa_1_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,82) = strpad('kappa_2_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,83) = strpad('kappa_2_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,84) = strpad('kappa_3_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,85) = strpad('kappa_3_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,86) = strpad('kappa_4_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,87) = strpad('kappa_4_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,88) = strpad('kappa_5_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,89) = strpad('kappa_5_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,90) = strpad('kappa_6_NCX in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,91) = strpad('kappa_6_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,92) = strpad('kappa_7_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,93) = strpad('kappa_8_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,94) = strpad('kappa_9_NaK in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,95) = strpad('kappa_K in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,96) = strpad('kappa_K1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,97) = strpad('kappa_Kp in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,98) = strpad('kappa_LCC_Ca1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,99) = strpad('kappa_LCC_Ca2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,100) = strpad('kappa_LCC_K1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,101) = strpad('kappa_LCC_K2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,102) = strpad('kappa_Na in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,103) = strpad('kappa_X00 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,104) = strpad('kappa_X01 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,105) = strpad('kappa_X10 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,106) = strpad('kappa_X11 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,107) = strpad('kappa_b1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,108) = strpad('kappa_b2 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,109) = strpad('kappa_d000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,110) = strpad('kappa_d001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,111) = strpad('kappa_d010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,112) = strpad('kappa_d011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,113) = strpad('kappa_d020 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,114) = strpad('kappa_d021 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,115) = strpad('kappa_f1_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,116) = strpad('kappa_f1_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,117) = strpad('kappa_f1_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,118) = strpad('kappa_f1_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,119) = strpad('kappa_f2_000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,120) = strpad('kappa_f2_001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,121) = strpad('kappa_f2_100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,122) = strpad('kappa_f2_101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,123) = strpad('kappa_f3_010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,124) = strpad('kappa_f3_011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,125) = strpad('kappa_f3_110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,126) = strpad('kappa_f3_111 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,127) = strpad('kappa_fCa00 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,128) = strpad('kappa_fCa01 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,129) = strpad('kappa_fCa02 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,130) = strpad('kappa_fCa10 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,131) = strpad('kappa_fCa11 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,132) = strpad('kappa_fCa12 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,133) = strpad('kappa_gK1 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,134) = strpad('kappa_gKp in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,135) = strpad('kappa_h000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,136) = strpad('kappa_h001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,137) = strpad('kappa_h100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,138) = strpad('kappa_h101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,139) = strpad('kappa_h200 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,140) = strpad('kappa_h201 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,141) = strpad('kappa_h300 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,142) = strpad('kappa_h301 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,143) = strpad('kappa_i00 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,144) = strpad('kappa_i10 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,145) = strpad('kappa_i20 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,146) = strpad('kappa_j000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,147) = strpad('kappa_j010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,148) = strpad('kappa_j100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,149) = strpad('kappa_j110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,150) = strpad('kappa_j200 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,151) = strpad('kappa_j210 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,152) = strpad('kappa_j300 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,153) = strpad('kappa_j310 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,154) = strpad('kappa_m000 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,155) = strpad('kappa_m001 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,156) = strpad('kappa_m010 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,157) = strpad('kappa_m011 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,158) = strpad('kappa_m100 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,159) = strpad('kappa_m101 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,160) = strpad('kappa_m110 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,161) = strpad('kappa_m111 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,162) = strpad('kappa_m200 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,163) = strpad('kappa_m201 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,164) = strpad('kappa_m210 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,165) = strpad('kappa_m211 in component BG_parameters (fmol_per_sec)');
    LEGEND_CONSTANTS(:,166) = strpad('nK in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,167) = strpad('nNae_NCX in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,168) = strpad('nNai_NCX in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,169) = strpad('zCa in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,170) = strpad('zF_5 in component BG_parameters (C_per_mol)');
    LEGEND_CONSTANTS(:,171) = strpad('zF_8 in component BG_parameters (C_per_mol)');
    LEGEND_CONSTANTS(:,172) = strpad('zK in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,173) = strpad('zNa in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,174) = strpad('z_fK1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,175) = strpad('z_fX in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,176) = strpad('z_fXi in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,177) = strpad('z_f_Kp in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,178) = strpad('z_fd in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,179) = strpad('z_ff1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,180) = strpad('z_ff2 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,181) = strpad('z_ff3 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,182) = strpad('z_fh in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,183) = strpad('z_fj in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,184) = strpad('z_fm in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,185) = strpad('z_rCa in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,186) = strpad('z_rK1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,187) = strpad('z_rX in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,188) = strpad('z_rXi in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,189) = strpad('z_r_Kp in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,190) = strpad('z_rd in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,191) = strpad('z_rf1 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,192) = strpad('z_rf2 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,193) = strpad('z_rf3 in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,194) = strpad('z_rh in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,195) = strpad('z_rj in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,196) = strpad('z_rm in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,197) = strpad('zf_NCX in component BG_parameters (dimensionless)');
    LEGEND_CONSTANTS(:,198) = strpad('zr_NCX in component BG_parameters (dimensionless)');
    LEGEND_VOI = strpad('t in component environment (second)');
    LEGEND_CONSTANTS(:,199) = strpad('R in component environment (J_per_K_per_mol)');
    LEGEND_CONSTANTS(:,200) = strpad('T in component environment (kelvin)');
    LEGEND_CONSTANTS(:,201) = strpad('F in component environment (C_per_mol)');
    LEGEND_CONSTANTS(:,202) = strpad('C_m in component environment (fF)');
    LEGEND_ALGEBRAIC(:,100) = strpad('V_mem in component environment (volt)');
    LEGEND_CONSTANTS(:,203) = strpad('q_Cae_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,204) = strpad('q_Cai_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,205) = strpad('q_Ke_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,206) = strpad('q_Ki_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,207) = strpad('q_Nae_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,208) = strpad('q_Nai_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,209) = strpad('q_mem_init in component environment (fC)');
    LEGEND_CONSTANTS(:,210) = strpad('q_CMDN_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,211) = strpad('q_CMDNCa_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,212) = strpad('q_TRPN_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,213) = strpad('q_TRPNCa_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,214) = strpad('q_P1_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,215) = strpad('q_P2_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,216) = strpad('q_P3_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,217) = strpad('q_P4_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,218) = strpad('q_P5_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,219) = strpad('q_P6_NCq_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,220) = strpad('q_H_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,221) = strpad('q_MgADP_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,222) = strpad('q_MgATP_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,223) = strpad('q_P7_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,224) = strpad('q_P_i_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,225) = strpad('q_P14_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,226) = strpad('q_P15_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,227) = strpad('q_P1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,228) = strpad('q_P2_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,229) = strpad('q_P3_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,230) = strpad('q_P4_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,231) = strpad('q_P5_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,232) = strpad('q_P6_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,233) = strpad('q_P10_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,234) = strpad('q_P11_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,235) = strpad('q_P12_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,236) = strpad('q_P13_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,237) = strpad('q_P8_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,238) = strpad('q_P9_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,239) = strpad('q_C_Kp_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,240) = strpad('q_O_Kp_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,241) = strpad('q_C_K1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,242) = strpad('q_O_K1_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,243) = strpad('q_S00_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,244) = strpad('q_S01_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,245) = strpad('q_S10_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,246) = strpad('q_S11_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,247) = strpad('q_S20_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,248) = strpad('q_S21_K_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,249) = strpad('q_S000_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,250) = strpad('q_S010_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,251) = strpad('q_S100_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,252) = strpad('q_S110_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,253) = strpad('q_S200_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,254) = strpad('q_S210_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,255) = strpad('q_S300_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,256) = strpad('q_S310_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,257) = strpad('q_S001_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,258) = strpad('q_S011_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,259) = strpad('q_S101_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,260) = strpad('q_S111_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,261) = strpad('q_S201_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,262) = strpad('q_S211_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,263) = strpad('q_S301_Na_init in component environment (fmol)');
    LEGEND_CONSTANTS(:,264) = strpad('q_S311_Na_init in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,2) = strpad('q_Ke in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,5) = strpad('q_Ki in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,7) = strpad('q_S00_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,8) = strpad('q_S01_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,9) = strpad('q_S10_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,10) = strpad('q_S11_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,11) = strpad('q_S20_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,12) = strpad('q_S21_K in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,13) = strpad('q_C_K1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,14) = strpad('q_O_K1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,15) = strpad('q_C_Kp in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,16) = strpad('q_O_Kp in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,17) = strpad('q_Nae in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,18) = strpad('q_Nai in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,19) = strpad('q_S000_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,20) = strpad('q_S010_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,22) = strpad('q_S100_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,24) = strpad('q_S110_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,26) = strpad('q_S200_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,28) = strpad('q_S210_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,30) = strpad('q_S300_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,32) = strpad('q_S310_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,34) = strpad('q_S001_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,36) = strpad('q_S011_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,38) = strpad('q_S101_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,40) = strpad('q_S111_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,42) = strpad('q_S201_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,44) = strpad('q_S211_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,46) = strpad('q_S301_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,48) = strpad('q_S311_Na in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,50) = strpad('q_Cae in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,51) = strpad('q_Cai in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,54) = strpad('q_H in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,57) = strpad('q_MgADP in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,58) = strpad('q_MgATP in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,61) = strpad('q_P7 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,64) = strpad('q_P_i in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,67) = strpad('q_P14 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,70) = strpad('q_P15 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,73) = strpad('q_P1 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,76) = strpad('q_P2 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,83) = strpad('q_P3 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,84) = strpad('q_P4 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,85) = strpad('q_P5 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,86) = strpad('q_P6 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,87) = strpad('q_P10 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,88) = strpad('q_P11 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,89) = strpad('q_P12 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,90) = strpad('q_P13 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,91) = strpad('q_P8 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,92) = strpad('q_P9 in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,93) = strpad('q_P1_NCX in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,94) = strpad('q_P2_NCX in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,95) = strpad('q_P3_NCX in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,96) = strpad('q_P4_NCX in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,97) = strpad('q_P5_NCX in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,98) = strpad('q_P6_NCX in component environment (fmol)');
    LEGEND_STATES(:,1) = strpad('q_Ke in component K1_channel (fmol)');
    LEGEND_STATES(:,2) = strpad('q_Ki in component K1_channel (fmol)');
    LEGEND_ALGEBRAIC(:,52) = strpad('q_CMDN in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,55) = strpad('q_CMDNCa in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,53) = strpad('q_TRPN in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,56) = strpad('q_TRPNCa in component environment (fmol)');
    LEGEND_STATES(:,3) = strpad('q_C_K1 in component K1_channel (fmol)');
    LEGEND_STATES(:,4) = strpad('q_O_K1 in component K1_channel (fmol)');
    LEGEND_STATES(:,5) = strpad('q_Ke in component Kp_channel (fmol)');
    LEGEND_STATES(:,6) = strpad('q_Ki in component Kp_channel (fmol)');
    LEGEND_STATES(:,7) = strpad('q_C_Kp in component Kp_channel (fmol)');
    LEGEND_STATES(:,8) = strpad('q_O_Kp in component Kp_channel (fmol)');
    LEGEND_STATES(:,9) = strpad('q_Nae in component Na_channel (fmol)');
    LEGEND_STATES(:,10) = strpad('q_Nai in component Na_channel (fmol)');
    LEGEND_STATES(:,11) = strpad('q_S000_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,12) = strpad('q_S010_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,13) = strpad('q_S100_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,14) = strpad('q_S110_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,15) = strpad('q_S200_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,16) = strpad('q_S210_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,17) = strpad('q_S300_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,18) = strpad('q_S310_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,19) = strpad('q_S001_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,20) = strpad('q_S011_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,21) = strpad('q_S101_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,22) = strpad('q_S111_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,23) = strpad('q_S201_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,24) = strpad('q_S211_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,25) = strpad('q_S301_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,26) = strpad('q_S311_Na in component Na_channel (fmol)');
    LEGEND_STATES(:,27) = strpad('q_Cao in component LCC (fmol)');
    LEGEND_STATES(:,28) = strpad('q_Cai in component LCC (fmol)');
    LEGEND_STATES(:,29) = strpad('q_Ki in component LCC (fmol)');
    LEGEND_STATES(:,30) = strpad('q_Ko in component LCC (fmol)');
    LEGEND_STATES(:,31) = strpad('q_Ke in component K_channel (fmol)');
    LEGEND_STATES(:,32) = strpad('q_Ki in component K_channel (fmol)');
    LEGEND_STATES(:,33) = strpad('q_S00_K in component K_channel (fmol)');
    LEGEND_STATES(:,34) = strpad('q_S01_K in component K_channel (fmol)');
    LEGEND_STATES(:,35) = strpad('q_S10_K in component K_channel (fmol)');
    LEGEND_STATES(:,36) = strpad('q_S11_K in component K_channel (fmol)');
    LEGEND_STATES(:,37) = strpad('q_S20_K in component K_channel (fmol)');
    LEGEND_STATES(:,38) = strpad('q_S21_K in component K_channel (fmol)');
    LEGEND_STATES(:,39) = strpad('q_Ke in component NaK_pump (fmol)');
    LEGEND_STATES(:,40) = strpad('q_Ki in component NaK_pump (fmol)');
    LEGEND_STATES(:,41) = strpad('q_Nae in component NaK_pump (fmol)');
    LEGEND_STATES(:,42) = strpad('q_Nai in component NaK_pump (fmol)');
    LEGEND_STATES(:,43) = strpad('q_H in component NaK_pump (fmol)');
    LEGEND_STATES(:,44) = strpad('q_MgADP in component NaK_pump (fmol)');
    LEGEND_STATES(:,45) = strpad('q_MgATP in component NaK_pump (fmol)');
    LEGEND_STATES(:,46) = strpad('q_P7 in component NaK_pump (fmol)');
    LEGEND_STATES(:,47) = strpad('q_P_i in component NaK_pump (fmol)');
    LEGEND_STATES(:,48) = strpad('q_P14 in component NaK_pump (fmol)');
    LEGEND_STATES(:,49) = strpad('q_P15 in component NaK_pump (fmol)');
    LEGEND_STATES(:,50) = strpad('q_P1 in component NaK_pump (fmol)');
    LEGEND_STATES(:,51) = strpad('q_P2 in component NaK_pump (fmol)');
    LEGEND_STATES(:,52) = strpad('q_P3 in component NaK_pump (fmol)');
    LEGEND_STATES(:,53) = strpad('q_P4 in component NaK_pump (fmol)');
    LEGEND_STATES(:,54) = strpad('q_P5 in component NaK_pump (fmol)');
    LEGEND_STATES(:,55) = strpad('q_P6 in component NaK_pump (fmol)');
    LEGEND_STATES(:,56) = strpad('q_P10 in component NaK_pump (fmol)');
    LEGEND_STATES(:,57) = strpad('q_P11 in component NaK_pump (fmol)');
    LEGEND_STATES(:,58) = strpad('q_P12 in component NaK_pump (fmol)');
    LEGEND_STATES(:,59) = strpad('q_P13 in component NaK_pump (fmol)');
    LEGEND_STATES(:,60) = strpad('q_P8 in component NaK_pump (fmol)');
    LEGEND_STATES(:,61) = strpad('q_P9 in component NaK_pump (fmol)');
    LEGEND_STATES(:,62) = strpad('q_Cae in component NCX (fmol)');
    LEGEND_STATES(:,63) = strpad('q_Cai in component NCX (fmol)');
    LEGEND_STATES(:,64) = strpad('q_Nae in component NCX (fmol)');
    LEGEND_STATES(:,65) = strpad('q_Nai in component NCX (fmol)');
    LEGEND_STATES(:,66) = strpad('q_P1_NCX in component NCX (fmol)');
    LEGEND_STATES(:,67) = strpad('q_P2_NCX in component NCX (fmol)');
    LEGEND_STATES(:,68) = strpad('q_P3_NCX in component NCX (fmol)');
    LEGEND_STATES(:,69) = strpad('q_P4_NCX in component NCX (fmol)');
    LEGEND_STATES(:,70) = strpad('q_P5_NCX in component NCX (fmol)');
    LEGEND_STATES(:,71) = strpad('q_P6_NCX in component NCX (fmol)');
    LEGEND_STATES(:,72) = strpad('q_CMDN in component CMDN_buffer (fmol)');
    LEGEND_STATES(:,73) = strpad('q_CMDNCa in component CMDN_buffer (fmol)');
    LEGEND_STATES(:,74) = strpad('q_Cai in component CMDN_buffer (fmol)');
    LEGEND_STATES(:,75) = strpad('q_TRPN in component TRPN_buffer (fmol)');
    LEGEND_STATES(:,76) = strpad('q_TRPNCa in component TRPN_buffer (fmol)');
    LEGEND_STATES(:,77) = strpad('q_Cai in component TRPN_buffer (fmol)');
    LEGEND_ALGEBRAIC(:,4) = strpad('I_stim in component environment (fA)');
    LEGEND_CONSTANTS(:,265) = strpad('stimPeriod in component environment (second)');
    LEGEND_CONSTANTS(:,266) = strpad('stimDuration in component environment (second)');
    LEGEND_ALGEBRAIC(:,1) = strpad('tPeriod in component environment (second)');
    LEGEND_STATES(:,78) = strpad('q_Ke_stim in component environment (fmol)');
    LEGEND_STATES(:,79) = strpad('q_Ki_stim in component environment (fmol)');
    LEGEND_ALGEBRAIC(:,6) = strpad('v_K_stim in component environment (fmol_per_sec)');
    LEGEND_STATES(:,80) = strpad('q_mem in component K_channel (fC)');
    LEGEND_STATES(:,81) = strpad('q_mem in component K1_channel (fC)');
    LEGEND_STATES(:,82) = strpad('q_mem in component Kp_channel (fC)');
    LEGEND_STATES(:,83) = strpad('q_mem in component Na_channel (fC)');
    LEGEND_STATES(:,84) = strpad('q_mem in component LCC (fC)');
    LEGEND_STATES(:,85) = strpad('q_mem in component NaK_pump (fC)');
    LEGEND_STATES(:,86) = strpad('q_mem in component NCX (fC)');
    LEGEND_STATES(:,87) = strpad('q_mem_stim in component environment (fC)');
    LEGEND_ALGEBRAIC(:,99) = strpad('q_mem in component environment (fC)');
    LEGEND_CONSTANTS(:,267) = strpad('I_pulse_LCC in component environment (fA)');
    LEGEND_CONSTANTS(:,268) = strpad('R in component constants (J_per_K_per_mol)');
    LEGEND_CONSTANTS(:,269) = strpad('T in component constants (kelvin)');
    LEGEND_CONSTANTS(:,270) = strpad('F in component constants (C_per_mol)');
    LEGEND_ALGEBRAIC(:,108) = strpad('mu_Nae in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,115) = strpad('mu_Nai in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,21) = strpad('mu_S000_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,23) = strpad('mu_S010_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,25) = strpad('mu_S100_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,27) = strpad('mu_S110_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,29) = strpad('mu_S200_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,31) = strpad('mu_S210_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,33) = strpad('mu_S300_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,35) = strpad('mu_S310_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,37) = strpad('mu_S001_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,39) = strpad('mu_S011_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,41) = strpad('mu_S101_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,43) = strpad('mu_S111_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,45) = strpad('mu_S201_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,47) = strpad('mu_S211_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,49) = strpad('mu_S301_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,122) = strpad('mu_S311_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,492) = strpad('v_Nae in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,493) = strpad('v_Nai in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,454) = strpad('v_S000_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,460) = strpad('v_S010_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,466) = strpad('v_S100_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,472) = strpad('v_S110_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,478) = strpad('v_S200_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,486) = strpad('v_S210_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,479) = strpad('v_S300_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,487) = strpad('v_S310_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,457) = strpad('v_S001_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,463) = strpad('v_S011_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,469) = strpad('v_S101_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,475) = strpad('v_S111_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,482) = strpad('v_S201_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,490) = strpad('v_S211_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,483) = strpad('v_S301_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,494) = strpad('v_S311_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,314) = strpad('Am_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,129) = strpad('Af_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,319) = strpad('Ar_Na in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,491) = strpad('v_Na in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,136) = strpad('Af_h000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,326) = strpad('Ar_h000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,329) = strpad('v_h000 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,143) = strpad('Af_h001 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,332) = strpad('Ar_h001 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,336) = strpad('v_h001 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,150) = strpad('Af_h100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,340) = strpad('Ar_h100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,343) = strpad('v_h100 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,157) = strpad('Af_h101 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,346) = strpad('Ar_h101 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,349) = strpad('v_h101 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,164) = strpad('Af_h200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,352) = strpad('Ar_h200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,356) = strpad('v_h200 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,171) = strpad('Af_h201 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,360) = strpad('Ar_h201 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,368) = strpad('v_h201 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,178) = strpad('Af_h300 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,373) = strpad('Ar_h300 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,381) = strpad('v_h300 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,187) = strpad('Af_h301 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,386) = strpad('Ar_h301 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,396) = strpad('v_h301 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,200) = strpad('Af_j000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,400) = strpad('Ar_j000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,409) = strpad('v_j000 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,205) = strpad('Af_j010 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,414) = strpad('Ar_j010 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,422) = strpad('v_j010 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,210) = strpad('Af_j100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,426) = strpad('Ar_j100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,432) = strpad('v_j100 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,215) = strpad('Af_j110 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,435) = strpad('Ar_j110 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,439) = strpad('v_j110 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,220) = strpad('Af_j200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,441) = strpad('Ar_j200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,445) = strpad('v_j200 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,225) = strpad('Af_j210 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,446) = strpad('Ar_j210 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,447) = strpad('v_j210 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,230) = strpad('Af_j300 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,448) = strpad('Ar_j300 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,449) = strpad('v_j300 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,236) = strpad('Af_j310 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,450) = strpad('Ar_j310 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,451) = strpad('v_j310 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,241) = strpad('Af_m000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,452) = strpad('Ar_m000 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,453) = strpad('v_m000 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,248) = strpad('Af_m001 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,455) = strpad('Ar_m001 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,456) = strpad('v_m001 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,253) = strpad('Af_m010 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,458) = strpad('Ar_m010 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,459) = strpad('v_m010 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,259) = strpad('Af_m011 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,461) = strpad('Ar_m011 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,462) = strpad('v_m011 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,264) = strpad('Af_m100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,464) = strpad('Ar_m100 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,465) = strpad('v_m100 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,271) = strpad('Af_m101 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,467) = strpad('Ar_m101 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,468) = strpad('v_m101 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,276) = strpad('Af_m110 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,470) = strpad('Ar_m110 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,471) = strpad('v_m110 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,283) = strpad('Af_m111 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,473) = strpad('Ar_m111 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,474) = strpad('v_m111 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,288) = strpad('Af_m200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,476) = strpad('Ar_m200 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,477) = strpad('v_m200 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,297) = strpad('Af_m201 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,480) = strpad('Ar_m201 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,481) = strpad('v_m201 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,302) = strpad('Af_m210 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,484) = strpad('Ar_m210 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,485) = strpad('v_m210 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,310) = strpad('Af_m211 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,488) = strpad('Ar_m211 in component Na_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,489) = strpad('v_m211 in component Na_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,101) = strpad('V_mem in component Na_channel (volt)');
    LEGEND_ALGEBRAIC(:,495) = strpad('I_mem in component Na_channel (fA)');
    LEGEND_ALGEBRAIC(:,109) = strpad('mu_Ke in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,116) = strpad('mu_Ki in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,123) = strpad('mu_S00_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,130) = strpad('mu_S01_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,137) = strpad('mu_S10_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,144) = strpad('mu_S11_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,151) = strpad('mu_S20_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,158) = strpad('mu_S21_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,320) = strpad('v_Ke in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,321) = strpad('v_Ki in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,289) = strpad('v_S00_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,290) = strpad('v_S01_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,303) = strpad('v_S10_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,304) = strpad('v_S11_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,315) = strpad('v_S20_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,322) = strpad('v_S21_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,221) = strpad('Am_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,165) = strpad('Af_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,226) = strpad('Ar_K in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,316) = strpad('v_K in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,172) = strpad('Af_X00 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,231) = strpad('Ar_X00 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,237) = strpad('v_X00 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,179) = strpad('Af_X01 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,242) = strpad('Ar_X01 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,249) = strpad('v_X01 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,188) = strpad('Af_X10 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,254) = strpad('Ar_X10 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,260) = strpad('v_X10 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,201) = strpad('Af_X11 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,265) = strpad('Ar_X11 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,272) = strpad('v_X11 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,206) = strpad('Af_i00 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,277) = strpad('Ar_i00 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,284) = strpad('v_i00 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,211) = strpad('Af_i10 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,291) = strpad('Ar_i10 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,298) = strpad('v_i10 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,216) = strpad('Af_i20 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,305) = strpad('Ar_i20 in component K_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,311) = strpad('v_i20 in component K_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,102) = strpad('V_mem in component K_channel (volt)');
    LEGEND_ALGEBRAIC(:,323) = strpad('I_mem in component K_channel (fA)');
    LEGEND_ALGEBRAIC(:,110) = strpad('mu_Ke in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,117) = strpad('mu_Ki in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,124) = strpad('mu_C_K1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,131) = strpad('mu_O_K1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,189) = strpad('v_Ke in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,190) = strpad('v_Ki in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,180) = strpad('v_C_K1 in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,191) = strpad('v_O_K1 in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,152) = strpad('Am_K1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,138) = strpad('Af_K1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,159) = strpad('Ar_K1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,181) = strpad('v_K1 in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,145) = strpad('Af_gK1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,166) = strpad('Ar_gK1 in component K1_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,173) = strpad('v_gK1 in component K1_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,103) = strpad('V_mem in component K1_channel (volt)');
    LEGEND_ALGEBRAIC(:,192) = strpad('I_mem in component K1_channel (fA)');
    LEGEND_ALGEBRAIC(:,111) = strpad('mu_Ke in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,118) = strpad('mu_Ki in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,125) = strpad('mu_C_Kp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,132) = strpad('mu_O_Kp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,193) = strpad('v_Ke in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,194) = strpad('v_Ki in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,182) = strpad('v_C_Kp in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,195) = strpad('v_O_Kp in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,153) = strpad('Am_Kp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,139) = strpad('Af_Kp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,160) = strpad('Ar_Kp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,183) = strpad('v_Kp in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,146) = strpad('Af_gKp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,167) = strpad('Ar_gKp in component Kp_channel (J_per_mol)');
    LEGEND_ALGEBRAIC(:,174) = strpad('v_gKp in component Kp_channel (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,104) = strpad('V_mem in component Kp_channel (volt)');
    LEGEND_ALGEBRAIC(:,196) = strpad('I_mem in component Kp_channel (fA)');
    LEGEND_ALGEBRAIC(:,112) = strpad('mu_Ke in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,119) = strpad('mu_Ki in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,126) = strpad('mu_Nae in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,133) = strpad('mu_Nai in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,140) = strpad('mu_H in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,147) = strpad('mu_MgADP in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,154) = strpad('mu_MgATP in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,161) = strpad('mu_P7 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,168) = strpad('mu_P_i in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,175) = strpad('mu_P14 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,184) = strpad('mu_P15 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,197) = strpad('mu_P1 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,202) = strpad('mu_P2 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,207) = strpad('mu_P3 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,212) = strpad('mu_P4 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,217) = strpad('mu_P5 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,222) = strpad('mu_P6 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,227) = strpad('mu_P10 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,232) = strpad('mu_P11 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,238) = strpad('mu_P12 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,243) = strpad('mu_P13 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,250) = strpad('mu_P8 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,255) = strpad('mu_P9 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,374) = strpad('v_Ke in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,361) = strpad('v_Ki in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,442) = strpad('v_Nae in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,401) = strpad('v_Nai in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,387) = strpad('v_H in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,415) = strpad('v_MgADP in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,402) = strpad('v_MgATP in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,427) = strpad('v_P7 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,388) = strpad('v_P_i in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,403) = strpad('v_P14 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,416) = strpad('v_P15 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,417) = strpad('v_P1 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,362) = strpad('v_P2 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,375) = strpad('v_P3 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,389) = strpad('v_P4 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,404) = strpad('v_P5 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,418) = strpad('v_P6 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,443) = strpad('v_P10 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,363) = strpad('v_P11 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,376) = strpad('v_P12 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,390) = strpad('v_P13 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,436) = strpad('v_P8 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,444) = strpad('v_P9 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,261) = strpad('Af_R1 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,341) = strpad('Ar_R1 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,344) = strpad('v_R1 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,266) = strpad('Af_R10 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,347) = strpad('Ar_R10 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,350) = strpad('v_R10 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,273) = strpad('Af_R11 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,353) = strpad('Ar_R11 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,357) = strpad('v_R11 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,278) = strpad('Af_R12 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,364) = strpad('Ar_R12 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,369) = strpad('v_R12 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,285) = strpad('Af_R13 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,377) = strpad('Ar_R13 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,382) = strpad('v_R13 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,292) = strpad('Af_R14 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,391) = strpad('Ar_R14 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,397) = strpad('v_R14 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,299) = strpad('Af_R15 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,405) = strpad('Ar_R15 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,410) = strpad('v_R15 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,306) = strpad('Af_R2 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,354) = strpad('Ar_R2 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,358) = strpad('v_R2 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,312) = strpad('Af_R3 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,365) = strpad('Ar_R3 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,370) = strpad('v_R3 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,317) = strpad('Af_R4 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,378) = strpad('Ar_R4 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,383) = strpad('v_R4 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,324) = strpad('Af_R5 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,392) = strpad('Ar_R5 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,398) = strpad('v_R5 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,327) = strpad('Af_R6 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,406) = strpad('Ar_R6 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,411) = strpad('v_R6 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,330) = strpad('Af_R7 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,419) = strpad('Ar_R7 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,423) = strpad('v_R7 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,333) = strpad('Af_R8 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,428) = strpad('Ar_R8 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,433) = strpad('v_R8 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,337) = strpad('Af_R9 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,437) = strpad('Ar_R9 in component NaK_pump (J_per_mol)');
    LEGEND_ALGEBRAIC(:,440) = strpad('v_R9 in component NaK_pump (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,105) = strpad('V_mem in component NaK_pump (volt)');
    LEGEND_ALGEBRAIC(:,438) = strpad('I_mem in component NaK_pump (fA)');
    LEGEND_ALGEBRAIC(:,113) = strpad('mu_Cae in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,120) = strpad('mu_Cai in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,127) = strpad('mu_Nae in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,134) = strpad('mu_Nai in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,141) = strpad('mu_P1_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,148) = strpad('mu_P2_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,155) = strpad('mu_P3_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,162) = strpad('mu_P4_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,169) = strpad('mu_P5_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,176) = strpad('mu_P6_NCX in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,267) = strpad('v_Cae in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,244) = strpad('v_Cai in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,279) = strpad('v_Nae in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,233) = strpad('v_Nai in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,293) = strpad('v_P1_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,245) = strpad('v_P2_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,256) = strpad('v_P3_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,268) = strpad('v_P4_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,280) = strpad('v_P5_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,294) = strpad('v_P6_NCX in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,185) = strpad('Af_r1 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,223) = strpad('Ar_r1 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,228) = strpad('v_r1 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,198) = strpad('Af_r2 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,234) = strpad('Ar_r2 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,239) = strpad('v_r2 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,203) = strpad('Af_r3 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,246) = strpad('Ar_r3 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,251) = strpad('v_r3 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,208) = strpad('Af_r4 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,257) = strpad('Ar_r4 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,262) = strpad('v_r4 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,213) = strpad('Af_r5 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,269) = strpad('Ar_r5 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,274) = strpad('v_r5 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,218) = strpad('Af_r6 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,281) = strpad('Ar_r6 in component NCX (J_per_mol)');
    LEGEND_ALGEBRAIC(:,286) = strpad('v_r6 in component NCX (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,106) = strpad('V_mem in component NCX (volt)');
    LEGEND_ALGEBRAIC(:,295) = strpad('I_mem in component NCX (fA)');
    LEGEND_CONSTANTS(:,271) = strpad('RT in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,107) = strpad('mu_E in component LCC (J_per_C)');
    LEGEND_ALGEBRAIC(:,142) = strpad('mu_mem_Ca in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,149) = strpad('mu_mem_K in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,338) = strpad('v_CaGHK_i in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,300) = strpad('v_CaGHK_o in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,307) = strpad('v_KGHK_i in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,308) = strpad('v_KGHK_o in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,114) = strpad('mu_Cai in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,121) = strpad('mu_Cao in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,128) = strpad('mu_Ki in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,135) = strpad('mu_Ko in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,219) = strpad('mu_S111 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,263) = strpad('mu_S121 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,224) = strpad('Af_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,229) = strpad('Ar_Ca1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,247) = strpad('v_Ca1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,296) = strpad('v_Ca2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,252) = strpad('v_K1 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,301) = strpad('v_K2 in component LCC (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,270) = strpad('Af_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,275) = strpad('Ar_Ca2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,235) = strpad('Af_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,240) = strpad('Ar_K1 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,282) = strpad('Af_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,287) = strpad('Ar_K2 in component LCC (J_per_mol)');
    LEGEND_ALGEBRAIC(:,309) = strpad('v_fCa00 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,313) = strpad('v_fCa01 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,318) = strpad('v_fCa02 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,325) = strpad('v_fCa10 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,328) = strpad('v_fCa11 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,331) = strpad('v_fCa12 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,434) = strpad('v_E_LCC in component LCC (fA)');
    LEGEND_ALGEBRAIC(:,429) = strpad('v_gate in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,334) = strpad('v_Ca_fgate in component LCC (fmol_per_sec)');
    LEGEND_CONSTANTS(:,272) = strpad('v_pulse in component LCC (fmol_per_sec)');
    LEGEND_STATES(:,88) = strpad('q_S000 in component LCC_gate (fmol)');
    LEGEND_STATES(:,89) = strpad('q_S010 in component LCC_gate (fmol)');
    LEGEND_STATES(:,90) = strpad('q_S020 in component LCC_gate (fmol)');
    LEGEND_STATES(:,91) = strpad('q_S100 in component LCC_gate (fmol)');
    LEGEND_STATES(:,92) = strpad('q_S110 in component LCC_gate (fmol)');
    LEGEND_STATES(:,93) = strpad('q_S120 in component LCC_gate (fmol)');
    LEGEND_STATES(:,94) = strpad('q_S001 in component LCC_gate (fmol)');
    LEGEND_STATES(:,95) = strpad('q_S011 in component LCC_gate (fmol)');
    LEGEND_STATES(:,96) = strpad('q_S021 in component LCC_gate (fmol)');
    LEGEND_STATES(:,97) = strpad('q_S101 in component LCC_gate (fmol)');
    LEGEND_STATES(:,98) = strpad('q_S111 in component LCC_gate (fmol)');
    LEGEND_STATES(:,99) = strpad('q_S121 in component LCC_gate (fmol)');
    LEGEND_ALGEBRAIC(:,3) = strpad('q_Ca_fgate in component LCC_gate (fmol)');
    LEGEND_ALGEBRAIC(:,156) = strpad('mu_S000 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,170) = strpad('mu_S010 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,186) = strpad('mu_S020 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,204) = strpad('mu_S100 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,214) = strpad('mu_S110 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,258) = strpad('mu_S120 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,163) = strpad('mu_S001 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,177) = strpad('mu_S011 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,199) = strpad('mu_S021 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,209) = strpad('mu_S101 in component LCC_gate (J_per_mol)');
    LEGEND_ALGEBRAIC(:,355) = strpad('v_f1_000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,359) = strpad('v_f2_000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,366) = strpad('v_f3_010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,371) = strpad('v_f1_100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,379) = strpad('v_f2_100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,384) = strpad('v_f3_110 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,335) = strpad('v_d000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,339) = strpad('v_d010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,342) = strpad('v_d020 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,345) = strpad('v_d001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,348) = strpad('v_d011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,351) = strpad('v_d021 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,393) = strpad('v_f1_001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,399) = strpad('v_f2_001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,407) = strpad('v_f3_011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,412) = strpad('v_f1_101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,420) = strpad('v_f2_101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,424) = strpad('v_f3_111 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,367) = strpad('v_S000 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,380) = strpad('v_S010 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,372) = strpad('v_S020 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,385) = strpad('v_S100 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,394) = strpad('v_S110 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,395) = strpad('v_S120 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,408) = strpad('v_S001 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,421) = strpad('v_S011 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,413) = strpad('v_S021 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,425) = strpad('v_S101 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,430) = strpad('v_S111 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,431) = strpad('v_S121 in component LCC_gate (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,59) = strpad('mu_TRPN in component TRPN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,62) = strpad('mu_TRPNCa in component TRPN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,65) = strpad('mu_Cai in component TRPN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,77) = strpad('v_TRPN in component TRPN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,78) = strpad('v_TRPNCa in component TRPN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,79) = strpad('v_Cai in component TRPN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,68) = strpad('Af_b1 in component TRPN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,71) = strpad('Ar_b1 in component TRPN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,74) = strpad('v_b1 in component TRPN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,60) = strpad('mu_CMDN in component CMDN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,63) = strpad('mu_CMDNCa in component CMDN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,66) = strpad('mu_Cai in component CMDN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,80) = strpad('v_CMDN in component CMDN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,81) = strpad('v_CMDNCa in component CMDN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,82) = strpad('v_Cai in component CMDN_buffer (fmol_per_sec)');
    LEGEND_ALGEBRAIC(:,69) = strpad('Af_b2 in component CMDN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,72) = strpad('Ar_b2 in component CMDN_buffer (J_per_mol)');
    LEGEND_ALGEBRAIC(:,75) = strpad('v_b2 in component CMDN_buffer (fmol_per_sec)');
    LEGEND_RATES(:,78) = strpad('d/dt q_Ke_stim in component environment (fmol)');
    LEGEND_RATES(:,79) = strpad('d/dt q_Ki_stim in component environment (fmol)');
    LEGEND_RATES(:,87) = strpad('d/dt q_mem_stim in component environment (fC)');
    LEGEND_RATES(:,9) = strpad('d/dt q_Nae in component Na_channel (fmol)');
    LEGEND_RATES(:,10) = strpad('d/dt q_Nai in component Na_channel (fmol)');
    LEGEND_RATES(:,11) = strpad('d/dt q_S000_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,12) = strpad('d/dt q_S010_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,13) = strpad('d/dt q_S100_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,14) = strpad('d/dt q_S110_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,15) = strpad('d/dt q_S200_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,16) = strpad('d/dt q_S210_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,17) = strpad('d/dt q_S300_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,18) = strpad('d/dt q_S310_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,19) = strpad('d/dt q_S001_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,20) = strpad('d/dt q_S011_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,21) = strpad('d/dt q_S101_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,22) = strpad('d/dt q_S111_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,23) = strpad('d/dt q_S201_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,24) = strpad('d/dt q_S211_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,25) = strpad('d/dt q_S301_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,26) = strpad('d/dt q_S311_Na in component Na_channel (fmol)');
    LEGEND_RATES(:,83) = strpad('d/dt q_mem in component Na_channel (fC)');
    LEGEND_RATES(:,31) = strpad('d/dt q_Ke in component K_channel (fmol)');
    LEGEND_RATES(:,32) = strpad('d/dt q_Ki in component K_channel (fmol)');
    LEGEND_RATES(:,33) = strpad('d/dt q_S00_K in component K_channel (fmol)');
    LEGEND_RATES(:,34) = strpad('d/dt q_S01_K in component K_channel (fmol)');
    LEGEND_RATES(:,35) = strpad('d/dt q_S10_K in component K_channel (fmol)');
    LEGEND_RATES(:,36) = strpad('d/dt q_S11_K in component K_channel (fmol)');
    LEGEND_RATES(:,37) = strpad('d/dt q_S20_K in component K_channel (fmol)');
    LEGEND_RATES(:,38) = strpad('d/dt q_S21_K in component K_channel (fmol)');
    LEGEND_RATES(:,80) = strpad('d/dt q_mem in component K_channel (fC)');
    LEGEND_RATES(:,1) = strpad('d/dt q_Ke in component K1_channel (fmol)');
    LEGEND_RATES(:,2) = strpad('d/dt q_Ki in component K1_channel (fmol)');
    LEGEND_RATES(:,3) = strpad('d/dt q_C_K1 in component K1_channel (fmol)');
    LEGEND_RATES(:,4) = strpad('d/dt q_O_K1 in component K1_channel (fmol)');
    LEGEND_RATES(:,81) = strpad('d/dt q_mem in component K1_channel (fC)');
    LEGEND_RATES(:,5) = strpad('d/dt q_Ke in component Kp_channel (fmol)');
    LEGEND_RATES(:,6) = strpad('d/dt q_Ki in component Kp_channel (fmol)');
    LEGEND_RATES(:,7) = strpad('d/dt q_C_Kp in component Kp_channel (fmol)');
    LEGEND_RATES(:,8) = strpad('d/dt q_O_Kp in component Kp_channel (fmol)');
    LEGEND_RATES(:,82) = strpad('d/dt q_mem in component Kp_channel (fC)');
    LEGEND_RATES(:,39) = strpad('d/dt q_Ke in component NaK_pump (fmol)');
    LEGEND_RATES(:,40) = strpad('d/dt q_Ki in component NaK_pump (fmol)');
    LEGEND_RATES(:,41) = strpad('d/dt q_Nae in component NaK_pump (fmol)');
    LEGEND_RATES(:,42) = strpad('d/dt q_Nai in component NaK_pump (fmol)');
    LEGEND_RATES(:,43) = strpad('d/dt q_H in component NaK_pump (fmol)');
    LEGEND_RATES(:,44) = strpad('d/dt q_MgADP in component NaK_pump (fmol)');
    LEGEND_RATES(:,45) = strpad('d/dt q_MgATP in component NaK_pump (fmol)');
    LEGEND_RATES(:,46) = strpad('d/dt q_P7 in component NaK_pump (fmol)');
    LEGEND_RATES(:,47) = strpad('d/dt q_P_i in component NaK_pump (fmol)');
    LEGEND_RATES(:,48) = strpad('d/dt q_P14 in component NaK_pump (fmol)');
    LEGEND_RATES(:,49) = strpad('d/dt q_P15 in component NaK_pump (fmol)');
    LEGEND_RATES(:,50) = strpad('d/dt q_P1 in component NaK_pump (fmol)');
    LEGEND_RATES(:,51) = strpad('d/dt q_P2 in component NaK_pump (fmol)');
    LEGEND_RATES(:,52) = strpad('d/dt q_P3 in component NaK_pump (fmol)');
    LEGEND_RATES(:,53) = strpad('d/dt q_P4 in component NaK_pump (fmol)');
    LEGEND_RATES(:,54) = strpad('d/dt q_P5 in component NaK_pump (fmol)');
    LEGEND_RATES(:,55) = strpad('d/dt q_P6 in component NaK_pump (fmol)');
    LEGEND_RATES(:,56) = strpad('d/dt q_P10 in component NaK_pump (fmol)');
    LEGEND_RATES(:,57) = strpad('d/dt q_P11 in component NaK_pump (fmol)');
    LEGEND_RATES(:,58) = strpad('d/dt q_P12 in component NaK_pump (fmol)');
    LEGEND_RATES(:,59) = strpad('d/dt q_P13 in component NaK_pump (fmol)');
    LEGEND_RATES(:,60) = strpad('d/dt q_P8 in component NaK_pump (fmol)');
    LEGEND_RATES(:,61) = strpad('d/dt q_P9 in component NaK_pump (fmol)');
    LEGEND_RATES(:,85) = strpad('d/dt q_mem in component NaK_pump (fC)');
    LEGEND_RATES(:,62) = strpad('d/dt q_Cae in component NCX (fmol)');
    LEGEND_RATES(:,63) = strpad('d/dt q_Cai in component NCX (fmol)');
    LEGEND_RATES(:,64) = strpad('d/dt q_Nae in component NCX (fmol)');
    LEGEND_RATES(:,65) = strpad('d/dt q_Nai in component NCX (fmol)');
    LEGEND_RATES(:,66) = strpad('d/dt q_P1_NCX in component NCX (fmol)');
    LEGEND_RATES(:,67) = strpad('d/dt q_P2_NCX in component NCX (fmol)');
    LEGEND_RATES(:,68) = strpad('d/dt q_P3_NCX in component NCX (fmol)');
    LEGEND_RATES(:,69) = strpad('d/dt q_P4_NCX in component NCX (fmol)');
    LEGEND_RATES(:,70) = strpad('d/dt q_P5_NCX in component NCX (fmol)');
    LEGEND_RATES(:,71) = strpad('d/dt q_P6_NCX in component NCX (fmol)');
    LEGEND_RATES(:,86) = strpad('d/dt q_mem in component NCX (fC)');
    LEGEND_RATES(:,84) = strpad('d/dt q_mem in component LCC (fC)');
    LEGEND_RATES(:,28) = strpad('d/dt q_Cai in component LCC (fmol)');
    LEGEND_RATES(:,27) = strpad('d/dt q_Cao in component LCC (fmol)');
    LEGEND_RATES(:,29) = strpad('d/dt q_Ki in component LCC (fmol)');
    LEGEND_RATES(:,30) = strpad('d/dt q_Ko in component LCC (fmol)');
    LEGEND_RATES(:,88) = strpad('d/dt q_S000 in component LCC_gate (fmol)');
    LEGEND_RATES(:,94) = strpad('d/dt q_S001 in component LCC_gate (fmol)');
    LEGEND_RATES(:,89) = strpad('d/dt q_S010 in component LCC_gate (fmol)');
    LEGEND_RATES(:,95) = strpad('d/dt q_S011 in component LCC_gate (fmol)');
    LEGEND_RATES(:,90) = strpad('d/dt q_S020 in component LCC_gate (fmol)');
    LEGEND_RATES(:,96) = strpad('d/dt q_S021 in component LCC_gate (fmol)');
    LEGEND_RATES(:,91) = strpad('d/dt q_S100 in component LCC_gate (fmol)');
    LEGEND_RATES(:,97) = strpad('d/dt q_S101 in component LCC_gate (fmol)');
    LEGEND_RATES(:,92) = strpad('d/dt q_S110 in component LCC_gate (fmol)');
    LEGEND_RATES(:,98) = strpad('d/dt q_S111 in component LCC_gate (fmol)');
    LEGEND_RATES(:,93) = strpad('d/dt q_S120 in component LCC_gate (fmol)');
    LEGEND_RATES(:,99) = strpad('d/dt q_S121 in component LCC_gate (fmol)');
    LEGEND_RATES(:,75) = strpad('d/dt q_TRPN in component TRPN_buffer (fmol)');
    LEGEND_RATES(:,76) = strpad('d/dt q_TRPNCa in component TRPN_buffer (fmol)');
    LEGEND_RATES(:,77) = strpad('d/dt q_Cai in component TRPN_buffer (fmol)');
    LEGEND_RATES(:,72) = strpad('d/dt q_CMDN in component CMDN_buffer (fmol)');
    LEGEND_RATES(:,73) = strpad('d/dt q_CMDNCa in component CMDN_buffer (fmol)');
    LEGEND_RATES(:,74) = strpad('d/dt q_Cai in component CMDN_buffer (fmol)');
    LEGEND_STATES  = LEGEND_STATES';
    LEGEND_ALGEBRAIC = LEGEND_ALGEBRAIC';
    LEGEND_RATES = LEGEND_RATES';
    LEGEND_CONSTANTS = LEGEND_CONSTANTS';
end

function [STATES, CONSTANTS] = initConsts()
    VOI = 0; CONSTANTS = []; STATES = []; ALGEBRAIC = [];
    CONSTANTS(:,1) = 1.3174;
    CONSTANTS(:,2) = 0.0073376;
    CONSTANTS(:,3) = 1565.0581;
    CONSTANTS(:,4) = 23718.0222;
    CONSTANTS(:,5) = 128.6868;
    CONSTANTS(:,6) = 53.3957;
    CONSTANTS(:,7) = 17499.8767;
    CONSTANTS(:,8) = 63435.6844;
    CONSTANTS(:,9) = 56566767727.4036;
    CONSTANTS(:,10) = 22.3033;
    CONSTANTS(:,11) = 28.5543;
    CONSTANTS(:,12) = 33923.3476;
    CONSTANTS(:,13) = 0.26529;
    CONSTANTS(:,14) = 1.5633e-05;
    CONSTANTS(:,15) = 315.1706;
    CONSTANTS(:,16) = 50.5317;
    CONSTANTS(:,17) = 16.5777;
    CONSTANTS(:,18) = 5076.1941;
    CONSTANTS(:,19) = 10.7528;
    CONSTANTS(:,20) = 37.2839;
    CONSTANTS(:,21) = 12774.6463;
    CONSTANTS(:,22) = 120516694.0958;
    CONSTANTS(:,23) = 2.8732;
    CONSTANTS(:,24) = 10.4383;
    CONSTANTS(:,25) = 5.7502;
    CONSTANTS(:,26) = 6831.4667;
    CONSTANTS(:,27) = 1.7361;
    CONSTANTS(:,28) = 1.155;
    CONSTANTS(:,29) = 319.1183;
    CONSTANTS(:,30) = 6250238.4012;
    CONSTANTS(:,31) = 160144852.2746;
    CONSTANTS(:,32) = 321178904.6865;
    CONSTANTS(:,33) = 9.9918e-08;
    CONSTANTS(:,34) = 0.32298;
    CONSTANTS(:,35) = 8.5423;
    CONSTANTS(:,36) = 0.2383;
    CONSTANTS(:,37) = 770290.0911;
    CONSTANTS(:,38) = 1.4805;
    CONSTANTS(:,39) = 407.3479;
    CONSTANTS(:,40) = 31093.1227;
    CONSTANTS(:,41) = 1.9159e-09;
    CONSTANTS(:,42) = 0.006193;
    CONSTANTS(:,43) = 0.0045694;
    CONSTANTS(:,44) = 14770.0739;
    CONSTANTS(:,45) = 22191.7214;
    CONSTANTS(:,46) = 12.0404;
    CONSTANTS(:,47) = 119580.5289;
    CONSTANTS(:,48) = 3.1105;
    CONSTANTS(:,49) = 10363474.1803;
    CONSTANTS(:,50) = 3.2141;
    CONSTANTS(:,51) = 199.44;
    CONSTANTS(:,52) = 170.6981;
    CONSTANTS(:,53) = 10036.4321;
    CONSTANTS(:,54) = 31550.6969;
    CONSTANTS(:,55) = 9874266.4618;
    CONSTANTS(:,56) = 22.0647;
    CONSTANTS(:,57) = 0.044337;
    CONSTANTS(:,58) = 1.329;
    CONSTANTS(:,59) = 41.6265;
    CONSTANTS(:,60) = 0.16293;
    CONSTANTS(:,61) = 0.022218;
    CONSTANTS(:,62) = 0.060187;
    CONSTANTS(:,63) = 0.059344;
    CONSTANTS(:,64) = 0.0080926;
    CONSTANTS(:,65) = 7.1044e-05;
    CONSTANTS(:,66) = 3.6718;
    CONSTANTS(:,67) = 0.017678;
    CONSTANTS(:,68) = 0.0024108;
    CONSTANTS(:,69) = 15967.3543;
    CONSTANTS(:,70) = 145.607;
    CONSTANTS(:,71) = 0.060187;
    CONSTANTS(:,72) = 37.1165;
    CONSTANTS(:,73) = 0.015668;
    CONSTANTS(:,74) = 1045757.658;
    CONSTANTS(:,75) = 311526.5915;
    CONSTANTS(:,76) = 1873089.8475;
    CONSTANTS(:,77) = 168.3622;
    CONSTANTS(:,78) = 22.4585;
    CONSTANTS(:,79) = 0.0049006;
    CONSTANTS(:,80) = 256862.245;
    CONSTANTS(:,81) = 104.5833;
    CONSTANTS(:,82) = 21141816.1231;
    CONSTANTS(:,83) = 270075.4148;
    CONSTANTS(:,84) = 6834.2872;
    CONSTANTS(:,85) = 906610.9954;
    CONSTANTS(:,86) = 21141816.1231;
    CONSTANTS(:,87) = 3509448.0698;
    CONSTANTS(:,88) = 256862.245;
    CONSTANTS(:,89) = 5858.2952;
    CONSTANTS(:,90) = 1.7753;
    CONSTANTS(:,91) = 8.3375;
    CONSTANTS(:,92) = 1.1523;
    CONSTANTS(:,93) = 1.1055;
    CONSTANTS(:,94) = 2150.4256;
    CONSTANTS(:,95) = 43947.9368;
    CONSTANTS(:,96) = 25.0154;
    CONSTANTS(:,97) = 252.3419;
    CONSTANTS(:,98) = 31.5432;
    CONSTANTS(:,99) = 58.9849;
    CONSTANTS(:,100) = 0.068076;
    CONSTANTS(:,101) = 0.1273;
    CONSTANTS(:,102) = 32.858;
    CONSTANTS(:,103) = 0.034684;
    CONSTANTS(:,104) = 0.20012;
    CONSTANTS(:,105) = 0.13462;
    CONSTANTS(:,106) = 0.77675;
    CONSTANTS(:,107) = 839.7697;
    CONSTANTS(:,108) = 1412.6324;
    CONSTANTS(:,109) = 369.4994;
    CONSTANTS(:,110) = 0.31102;
    CONSTANTS(:,111) = 9.1161;
    CONSTANTS(:,112) = 0.0076733;
    CONSTANTS(:,113) = 17.0469;
    CONSTANTS(:,114) = 0.014349;
    CONSTANTS(:,115) = 0.68071;
    CONSTANTS(:,116) = 0.00057297;
    CONSTANTS(:,117) = 3.3802;
    CONSTANTS(:,118) = 0.0028452;
    CONSTANTS(:,119) = 1.2467;
    CONSTANTS(:,120) = 0.0010494;
    CONSTANTS(:,121) = 6.1907;
    CONSTANTS(:,122) = 0.0052109;
    CONSTANTS(:,123) = 3502.1028;
    CONSTANTS(:,124) = 2.9478;
    CONSTANTS(:,125) = 17390.563;
    CONSTANTS(:,126) = 14.6381;
    CONSTANTS(:,127) = 106492.3187;
    CONSTANTS(:,128) = 2627.333;
    CONSTANTS(:,129) = 4913.0371;
    CONSTANTS(:,130) = 528814.1044;
    CONSTANTS(:,131) = 13046.6757;
    CONSTANTS(:,132) = 24396.9083;
    CONSTANTS(:,133) = 848.2812;
    CONSTANTS(:,134) = 24.0195;
    CONSTANTS(:,135) = 0.045709;
    CONSTANTS(:,136) = 1.4141e-08;
    CONSTANTS(:,137) = 21.4544;
    CONSTANTS(:,138) = 6.6373e-06;
    CONSTANTS(:,139) = 3356.675;
    CONSTANTS(:,140) = 0.0010384;
    CONSTANTS(:,141) = 175057.5863;
    CONSTANTS(:,142) = 0.054157;
    CONSTANTS(:,143) = 7.7389;
    CONSTANTS(:,144) = 60.0742;
    CONSTANTS(:,145) = 116.5836;
    CONSTANTS(:,146) = 0.017824;
    CONSTANTS(:,147) = 7.4736e-09;
    CONSTANTS(:,148) = 8.3662;
    CONSTANTS(:,149) = 3.5079e-06;
    CONSTANTS(:,150) = 1308.9427;
    CONSTANTS(:,151) = 0.00054883;
    CONSTANTS(:,152) = 68264.0876;
    CONSTANTS(:,153) = 0.028623;
    CONSTANTS(:,154) = 5117405.6443;
    CONSTANTS(:,155) = 1.5832;
    CONSTANTS(:,156) = 2.1457;
    CONSTANTS(:,157) = 6.6381e-07;
    CONSTANTS(:,158) = 1601300127.6001;
    CONSTANTS(:,159) = 495.389;
    CONSTANTS(:,160) = 671.4132;
    CONSTANTS(:,161) = 0.00020771;
    CONSTANTS(:,162) = 125266701374.7363;
    CONSTANTS(:,163) = 38753.3515;
    CONSTANTS(:,164) = 52523.3901;
    CONSTANTS(:,165) = 0.016249;
    CONSTANTS(:,166) = 0.5;
    CONSTANTS(:,167) = 3;
    CONSTANTS(:,168) = 3;
    CONSTANTS(:,169) = 2;
    CONSTANTS(:,170) = -5301.979;
    CONSTANTS(:,171) = -91183.021;
    CONSTANTS(:,172) = 1;
    CONSTANTS(:,173) = 1;
    CONSTANTS(:,174) = 0.033569;
    CONSTANTS(:,175) = 0.51923;
    CONSTANTS(:,176) = 0;
    CONSTANTS(:,177) = 0;
    CONSTANTS(:,178) = 2.1404;
    CONSTANTS(:,179) = -1.1495;
    CONSTANTS(:,180) = 0.72162;
    CONSTANTS(:,181) = 4.2933;
    CONSTANTS(:,182) = -4.1892;
    CONSTANTS(:,183) = -4.0381;
    CONSTANTS(:,184) = 0.49541;
    CONSTANTS(:,185) = 2;
    CONSTANTS(:,186) = 3.1153;
    CONSTANTS(:,187) = -0.73169;
    CONSTANTS(:,188) = 0.83216;
    CONSTANTS(:,189) = -4.4669;
    CONSTANTS(:,190) = -2.1404;
    CONSTANTS(:,191) = 1.8993;
    CONSTANTS(:,192) = -0.52288;
    CONSTANTS(:,193) = 0;
    CONSTANTS(:,194) = 1.2995;
    CONSTANTS(:,195) = 1.4281;
    CONSTANTS(:,196) = -2.4284;
    CONSTANTS(:,197) = -0.55679;
    CONSTANTS(:,198) = 0.44321;
    CONSTANTS(:,199) = 8.314;
    CONSTANTS(:,200) = 310;
    CONSTANTS(:,201) = 96485;
    CONSTANTS(:,202) = 153400;
    CONSTANTS(:,203) = 9.3276;
    CONSTANTS(:,204) = 0.00456;
    CONSTANTS(:,205) = 27.9828;
    CONSTANTS(:,206) = 5510;
    CONSTANTS(:,207) = 725.48;
    CONSTANTS(:,208) = 380;
    CONSTANTS(:,209) = -13039;
    CONSTANTS(:,210) = 1.8088;
    CONSTANTS(:,211) = 0.0912;
    CONSTANTS(:,212) = 2.1452;
    CONSTANTS(:,213) = 0.51484;
    CONSTANTS(:,214) = 0.00072174;
    CONSTANTS(:,215) = 0.00072174;
    CONSTANTS(:,216) = 0.00072174;
    CONSTANTS(:,217) = 0.00072174;
    CONSTANTS(:,218) = 0.00072174;
    CONSTANTS(:,219) = 0.00072174;
    CONSTANTS(:,220) = 0.0030534;
    CONSTANTS(:,221) = 1.33;
    CONSTANTS(:,222) = 264.1;
    CONSTANTS(:,223) = 0.0078543;
    CONSTANTS(:,224) = 15.0898;
    CONSTANTS(:,225) = 0.0078543;
    CONSTANTS(:,226) = 0.0078543;
    CONSTANTS(:,227) = 0.0078543;
    CONSTANTS(:,228) = 0.0078543;
    CONSTANTS(:,229) = 0.0078543;
    CONSTANTS(:,230) = 0.0078543;
    CONSTANTS(:,231) = 0.0078543;
    CONSTANTS(:,232) = 0.0078543;
    CONSTANTS(:,233) = 0.0078543;
    CONSTANTS(:,234) = 0.0078543;
    CONSTANTS(:,235) = 0.0078543;
    CONSTANTS(:,236) = 0.0078543;
    CONSTANTS(:,237) = 0.0078543;
    CONSTANTS(:,238) = 0.0078543;
    CONSTANTS(:,239) = 9.6314e-07;
    CONSTANTS(:,240) = 2.4078e-07;
    CONSTANTS(:,241) = 5.6606e-06;
    CONSTANTS(:,242) = 1.4151e-06;
    CONSTANTS(:,243) = 4.5648e-06;
    CONSTANTS(:,244) = 1.1412e-06;
    CONSTANTS(:,245) = 2.2824e-06;
    CONSTANTS(:,246) = 5.706e-07;
    CONSTANTS(:,247) = 2.853e-07;
    CONSTANTS(:,248) = 7.1325e-08;
    CONSTANTS(:,249) = 0.00012033;
    CONSTANTS(:,250) = 1.337e-05;
    CONSTANTS(:,251) = 4.0111e-05;
    CONSTANTS(:,252) = 4.4568e-06;
    CONSTANTS(:,253) = 4.4568e-06;
    CONSTANTS(:,254) = 4.952e-07;
    CONSTANTS(:,255) = 1.6507e-07;
    CONSTANTS(:,256) = 1.8341e-08;
    CONSTANTS(:,257) = 1.337e-05;
    CONSTANTS(:,258) = 1.4856e-06;
    CONSTANTS(:,259) = 4.4568e-06;
    CONSTANTS(:,260) = 4.952e-07;
    CONSTANTS(:,261) = 4.952e-07;
    CONSTANTS(:,262) = 5.5022e-08;
    CONSTANTS(:,263) = 1.8341e-08;
    CONSTANTS(:,264) = 2.0379e-09;
    STATES(:,1) = 0;
    STATES(:,2) = 0;
    STATES(:,3) = 0;
    STATES(:,4) = 0;
    STATES(:,5) = 0;
    STATES(:,6) = 0;
    STATES(:,7) = 0;
    STATES(:,8) = 0;
    STATES(:,9) = 0;
    STATES(:,10) = 0;
    STATES(:,11) = 0;
    STATES(:,12) = 0;
    STATES(:,13) = 0;
    STATES(:,14) = 0;
    STATES(:,15) = 0;
    STATES(:,16) = 0;
    STATES(:,17) = 0;
    STATES(:,18) = 0;
    STATES(:,19) = 0;
    STATES(:,20) = 0;
    STATES(:,21) = 0;
    STATES(:,22) = 0;
    STATES(:,23) = 0;
    STATES(:,24) = 0;
    STATES(:,25) = 0;
    STATES(:,26) = 0;
    STATES(:,27) = 1e-16;
    STATES(:,28) = 1e-16;
    STATES(:,29) = 1e-16;
    STATES(:,30) = 1e-16;
    STATES(:,31) = 0;
    STATES(:,32) = 0;
    STATES(:,33) = 0;
    STATES(:,34) = 0;
    STATES(:,35) = 0;
    STATES(:,36) = 0;
    STATES(:,37) = 0;
    STATES(:,38) = 0;
    STATES(:,39) = 0;
    STATES(:,40) = 0;
    STATES(:,41) = 0;
    STATES(:,42) = 0;
    STATES(:,43) = 0;
    STATES(:,44) = 0;
    STATES(:,45) = 0;
    STATES(:,46) = 0;
    STATES(:,47) = 0;
    STATES(:,48) = 0;
    STATES(:,49) = 0;
    STATES(:,50) = 0;
    STATES(:,51) = 0;
    STATES(:,52) = 0;
    STATES(:,53) = 0;
    STATES(:,54) = 0;
    STATES(:,55) = 0;
    STATES(:,56) = 0;
    STATES(:,57) = 0;
    STATES(:,58) = 0;
    STATES(:,59) = 0;
    STATES(:,60) = 0;
    STATES(:,61) = 0;
    STATES(:,62) = 0;
    STATES(:,63) = 0;
    STATES(:,64) = 0;
    STATES(:,65) = 0;
    STATES(:,66) = 0;
    STATES(:,67) = 0;
    STATES(:,68) = 0;
    STATES(:,69) = 0;
    STATES(:,70) = 0;
    STATES(:,71) = 0;
    STATES(:,72) = 0;
    STATES(:,73) = 0;
    STATES(:,74) = 0;
    STATES(:,75) = 0;
    STATES(:,76) = 0;
    STATES(:,77) = 0;
    CONSTANTS(:,265) = 1;
    CONSTANTS(:,266) = 0.0001;
    STATES(:,78) = 0;
    STATES(:,79) = 0;
    STATES(:,80) = 0;
    STATES(:,81) = 0;
    STATES(:,82) = 0;
    STATES(:,83) = 0;
    STATES(:,84) = 0;
    STATES(:,85) = 0;
    STATES(:,86) = 0;
    STATES(:,87) = 0;
    CONSTANTS(:,267) = 0;
    CONSTANTS(:,268) = 8.31;
    CONSTANTS(:,269) = 310;
    CONSTANTS(:,270) = 96485;
    STATES(:,88) = 3.6989e-07;
    STATES(:,89) = 7.3239e-05;
    STATES(:,90) = 3.6989e-07;
    STATES(:,91) = 3.7363e-09;
    STATES(:,92) = 7.3979e-07;
    STATES(:,93) = 3.7363e-09;
    STATES(:,94) = 4.1099e-08;
    STATES(:,95) = 8.1377e-06;
    STATES(:,96) = 4.1099e-08;
    STATES(:,97) = 4.1514e-10;
    STATES(:,98) = 8.2199e-08;
    STATES(:,99) = 4.1514e-10;
    CONSTANTS(:,271) =  CONSTANTS(:,199).*CONSTANTS(:,200);
    CONSTANTS(:,272) = CONSTANTS(:,267)./( CONSTANTS(:,169).*CONSTANTS(:,201));
    if (isempty(STATES)), warning('Initial values for states not set');, end
end

function [RATES, ALGEBRAIC] = computeRates(VOI, STATES, CONSTANTS)
    disp(VOI)
    global algebraicVariableCount;
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        ALGEBRAIC = zeros(1, algebraicVariableCount);
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        ALGEBRAIC = zeros(statesRowCount, algebraicVariableCount);
        RATES = zeros(statesRowCount, statesColumnCount);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,1) = VOI -  floor(VOI./CONSTANTS(:,265)).*CONSTANTS(:,265);
    ALGEBRAIC(:,4) = piecewise({ALGEBRAIC(:,1)>=0.300000&ALGEBRAIC(:,1)<=0.300000+CONSTANTS(:,266), ( 0.0300000.*CONSTANTS(:,202))./CONSTANTS(:,266) }, 0.000000);
    RATES(:,87) = ALGEBRAIC(:,4);
    ALGEBRAIC(:,6) =  (1.00000./CONSTANTS(:,201)).*ALGEBRAIC(:,4);
    RATES(:,78) =  - ALGEBRAIC(:,6);
    RATES(:,79) = ALGEBRAIC(:,6);
    ALGEBRAIC(:,53) = CONSTANTS(:,212)+STATES(:,75);
    ALGEBRAIC(:,59) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,72).*ALGEBRAIC(:,53));
    ALGEBRAIC(:,51) = CONSTANTS(:,204)+STATES(:,28)+STATES(:,63)+STATES(:,74)+STATES(:,77);
    ALGEBRAIC(:,65) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,68) = ALGEBRAIC(:,65)+ALGEBRAIC(:,59);
    ALGEBRAIC(:,56) = CONSTANTS(:,213)+STATES(:,76);
    ALGEBRAIC(:,62) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,73).*ALGEBRAIC(:,56));
    ALGEBRAIC(:,71) = ALGEBRAIC(:,62);
    ALGEBRAIC(:,74) =  CONSTANTS(:,107).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,71)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,77) =  - ALGEBRAIC(:,74);
    RATES(:,75) = ALGEBRAIC(:,77);
    ALGEBRAIC(:,78) = ALGEBRAIC(:,74);
    RATES(:,76) = ALGEBRAIC(:,78);
    ALGEBRAIC(:,79) =  - ALGEBRAIC(:,74);
    RATES(:,77) = ALGEBRAIC(:,79);
    ALGEBRAIC(:,52) = CONSTANTS(:,210)+STATES(:,72);
    ALGEBRAIC(:,60) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,56).*ALGEBRAIC(:,52));
    ALGEBRAIC(:,66) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,69) = ALGEBRAIC(:,66)+ALGEBRAIC(:,60);
    ALGEBRAIC(:,55) = CONSTANTS(:,211)+STATES(:,73);
    ALGEBRAIC(:,63) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,57).*ALGEBRAIC(:,55));
    ALGEBRAIC(:,72) = ALGEBRAIC(:,63);
    ALGEBRAIC(:,75) =  CONSTANTS(:,108).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,72)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,80) =  - ALGEBRAIC(:,75);
    RATES(:,72) = ALGEBRAIC(:,80);
    ALGEBRAIC(:,81) = ALGEBRAIC(:,75);
    RATES(:,73) = ALGEBRAIC(:,81);
    ALGEBRAIC(:,82) =  - ALGEBRAIC(:,75);
    RATES(:,74) = ALGEBRAIC(:,82);
    ALGEBRAIC(:,13) = CONSTANTS(:,241)+STATES(:,3);
    ALGEBRAIC(:,124) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,58).*ALGEBRAIC(:,13));
    ALGEBRAIC(:,99) = CONSTANTS(:,209)+STATES(:,80)+STATES(:,81)+STATES(:,82)+STATES(:,83)+STATES(:,84)+STATES(:,85)+STATES(:,86)+STATES(:,87);
    ALGEBRAIC(:,103) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,145) = ALGEBRAIC(:,124)+ CONSTANTS(:,174).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,14) = CONSTANTS(:,242)+STATES(:,4);
    ALGEBRAIC(:,131) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,69).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,166) = ALGEBRAIC(:,131)+ CONSTANTS(:,186).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,173) =  CONSTANTS(:,133).*(exp(ALGEBRAIC(:,145)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,166)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,180) =  - ALGEBRAIC(:,173);
    RATES(:,3) = ALGEBRAIC(:,180);
    ALGEBRAIC(:,15) = CONSTANTS(:,239)+STATES(:,7);
    ALGEBRAIC(:,125) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,59).*ALGEBRAIC(:,15));
    ALGEBRAIC(:,104) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,146) = ALGEBRAIC(:,125)+ CONSTANTS(:,177).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,16) = CONSTANTS(:,240)+STATES(:,8);
    ALGEBRAIC(:,132) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,70).*ALGEBRAIC(:,16));
    ALGEBRAIC(:,167) = ALGEBRAIC(:,132)+ CONSTANTS(:,189).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,174) =  CONSTANTS(:,134).*(exp(ALGEBRAIC(:,146)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,167)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,182) =  - ALGEBRAIC(:,174);
    RATES(:,7) = ALGEBRAIC(:,182);
    ALGEBRAIC(:,152) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,2) = CONSTANTS(:,205)+STATES(:,31)+STATES(:,1)+STATES(:,5)+STATES(:,30)+STATES(:,39)+STATES(:,78);
    ALGEBRAIC(:,110) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,5) = CONSTANTS(:,206)+STATES(:,32)+STATES(:,2)+STATES(:,6)+STATES(:,29)+STATES(:,40)+STATES(:,79);
    ALGEBRAIC(:,117) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,138) = ALGEBRAIC(:,117)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,103)+ALGEBRAIC(:,131)+ CONSTANTS(:,166).*ALGEBRAIC(:,110);
    ALGEBRAIC(:,159) = ALGEBRAIC(:,110)+ALGEBRAIC(:,131)+ CONSTANTS(:,166).*ALGEBRAIC(:,110);
    ALGEBRAIC(:,181) = piecewise({ALGEBRAIC(:,152)==0.000000,  CONSTANTS(:,96).*(exp(ALGEBRAIC(:,138)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,159)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,96).*ALGEBRAIC(:,152))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,152)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,138)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,159)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,189) = ALGEBRAIC(:,181) -  CONSTANTS(:,166).*(ALGEBRAIC(:,181) - ALGEBRAIC(:,181));
    RATES(:,1) = ALGEBRAIC(:,189);
    ALGEBRAIC(:,190) =  - ALGEBRAIC(:,181);
    RATES(:,2) = ALGEBRAIC(:,190);
    ALGEBRAIC(:,191) = ALGEBRAIC(:,173) - (ALGEBRAIC(:,181) - ALGEBRAIC(:,181));
    RATES(:,4) = ALGEBRAIC(:,191);
    ALGEBRAIC(:,192) =  CONSTANTS(:,201).*((  - CONSTANTS(:,172).*ALGEBRAIC(:,181)+ CONSTANTS(:,186).*ALGEBRAIC(:,173)) -  CONSTANTS(:,174).*ALGEBRAIC(:,173));
    RATES(:,81) = ALGEBRAIC(:,192);
    ALGEBRAIC(:,153) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,118) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,139) = ALGEBRAIC(:,118)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,104)+ALGEBRAIC(:,132);
    ALGEBRAIC(:,111) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,160) = ALGEBRAIC(:,111)+ALGEBRAIC(:,132);
    ALGEBRAIC(:,183) = piecewise({ALGEBRAIC(:,153)==0.000000,  CONSTANTS(:,97).*(exp(ALGEBRAIC(:,139)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,160)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,97).*ALGEBRAIC(:,153))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,153)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,139)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,160)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,193) = ALGEBRAIC(:,183);
    RATES(:,5) = ALGEBRAIC(:,193);
    ALGEBRAIC(:,194) =  - ALGEBRAIC(:,183);
    RATES(:,6) = ALGEBRAIC(:,194);
    ALGEBRAIC(:,195) = ALGEBRAIC(:,174) - (ALGEBRAIC(:,183) - ALGEBRAIC(:,183));
    RATES(:,8) = ALGEBRAIC(:,195);
    ALGEBRAIC(:,196) =  CONSTANTS(:,201).*((  - CONSTANTS(:,172).*ALGEBRAIC(:,183)+ CONSTANTS(:,189).*ALGEBRAIC(:,174)) -  CONSTANTS(:,177).*ALGEBRAIC(:,174));
    RATES(:,82) = ALGEBRAIC(:,196);
    ALGEBRAIC(:,93) = CONSTANTS(:,214)+STATES(:,66);
    ALGEBRAIC(:,141) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,31).*ALGEBRAIC(:,93));
    ALGEBRAIC(:,185) = ALGEBRAIC(:,141);
    ALGEBRAIC(:,18) = CONSTANTS(:,208)+STATES(:,10)+STATES(:,42)+STATES(:,65);
    ALGEBRAIC(:,134) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,94) = CONSTANTS(:,215)+STATES(:,67);
    ALGEBRAIC(:,148) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,39).*ALGEBRAIC(:,94));
    ALGEBRAIC(:,223) =  CONSTANTS(:,168).*ALGEBRAIC(:,134)+ALGEBRAIC(:,148);
    ALGEBRAIC(:,228) =  CONSTANTS(:,80).*(exp(ALGEBRAIC(:,185)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,223)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,233) =  CONSTANTS(:,168).*ALGEBRAIC(:,228);
    RATES(:,65) = ALGEBRAIC(:,233);
    ALGEBRAIC(:,120) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,198) = ALGEBRAIC(:,148)+ALGEBRAIC(:,120);
    ALGEBRAIC(:,95) = CONSTANTS(:,216)+STATES(:,68);
    ALGEBRAIC(:,155) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,45).*ALGEBRAIC(:,95));
    ALGEBRAIC(:,234) = ALGEBRAIC(:,155);
    ALGEBRAIC(:,239) =  CONSTANTS(:,82).*(exp(ALGEBRAIC(:,198)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,234)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,244) =  - ALGEBRAIC(:,239);
    RATES(:,63) = ALGEBRAIC(:,244);
    ALGEBRAIC(:,245) = ALGEBRAIC(:,228) - ALGEBRAIC(:,239);
    RATES(:,67) = ALGEBRAIC(:,245);
    ALGEBRAIC(:,203) = ALGEBRAIC(:,155);
    ALGEBRAIC(:,96) = CONSTANTS(:,217)+STATES(:,69);
    ALGEBRAIC(:,162) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,47).*ALGEBRAIC(:,96));
    ALGEBRAIC(:,246) = ALGEBRAIC(:,162);
    ALGEBRAIC(:,251) =  CONSTANTS(:,84).*(exp(ALGEBRAIC(:,203)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,246)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,256) = ALGEBRAIC(:,239) - ALGEBRAIC(:,251);
    RATES(:,68) = ALGEBRAIC(:,256);
    ALGEBRAIC(:,208) = ALGEBRAIC(:,162);
    ALGEBRAIC(:,50) = CONSTANTS(:,203)+STATES(:,27)+STATES(:,62);
    ALGEBRAIC(:,113) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,60).*ALGEBRAIC(:,50));
    ALGEBRAIC(:,97) = CONSTANTS(:,218)+STATES(:,70);
    ALGEBRAIC(:,169) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,49).*ALGEBRAIC(:,97));
    ALGEBRAIC(:,257) = ALGEBRAIC(:,169)+ALGEBRAIC(:,113);
    ALGEBRAIC(:,262) =  CONSTANTS(:,86).*(exp(ALGEBRAIC(:,208)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,257)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,267) = ALGEBRAIC(:,262);
    RATES(:,62) = ALGEBRAIC(:,267);
    ALGEBRAIC(:,268) =  - ALGEBRAIC(:,262)+ALGEBRAIC(:,251);
    RATES(:,69) = ALGEBRAIC(:,268);
    ALGEBRAIC(:,17) = CONSTANTS(:,207)+STATES(:,9)+STATES(:,41)+STATES(:,64);
    ALGEBRAIC(:,127) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,213) = ALGEBRAIC(:,169)+ CONSTANTS(:,167).*ALGEBRAIC(:,127);
    ALGEBRAIC(:,98) = CONSTANTS(:,219)+STATES(:,71);
    ALGEBRAIC(:,176) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,51).*ALGEBRAIC(:,98));
    ALGEBRAIC(:,269) = ALGEBRAIC(:,176);
    ALGEBRAIC(:,274) =  CONSTANTS(:,88).*(exp(ALGEBRAIC(:,213)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,269)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,279) =   - CONSTANTS(:,167).*ALGEBRAIC(:,274);
    RATES(:,64) = ALGEBRAIC(:,279);
    ALGEBRAIC(:,280) =  - ALGEBRAIC(:,274)+ALGEBRAIC(:,262);
    RATES(:,70) = ALGEBRAIC(:,280);
    ALGEBRAIC(:,7) = CONSTANTS(:,243)+STATES(:,33);
    ALGEBRAIC(:,123) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,5).*ALGEBRAIC(:,7));
    ALGEBRAIC(:,102) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,172) = ALGEBRAIC(:,123)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,9) = CONSTANTS(:,245)+STATES(:,35);
    ALGEBRAIC(:,137) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,17).*ALGEBRAIC(:,9));
    ALGEBRAIC(:,231) = ALGEBRAIC(:,137)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,237) =  CONSTANTS(:,103).*(exp(ALGEBRAIC(:,172)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,231)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,206) = ALGEBRAIC(:,123)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,8) = CONSTANTS(:,244)+STATES(:,34);
    ALGEBRAIC(:,130) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,10).*ALGEBRAIC(:,8));
    ALGEBRAIC(:,277) = ALGEBRAIC(:,130)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,284) =  CONSTANTS(:,143).*(exp(ALGEBRAIC(:,206)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,277)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,289) =  - ALGEBRAIC(:,237) - ALGEBRAIC(:,284);
    RATES(:,33) = ALGEBRAIC(:,289);
    ALGEBRAIC(:,179) = ALGEBRAIC(:,130)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,10) = CONSTANTS(:,246)+STATES(:,36);
    ALGEBRAIC(:,144) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,23).*ALGEBRAIC(:,10));
    ALGEBRAIC(:,242) = ALGEBRAIC(:,144)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,249) =  CONSTANTS(:,104).*(exp(ALGEBRAIC(:,179)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,242)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,290) =  - ALGEBRAIC(:,249)+ALGEBRAIC(:,284);
    RATES(:,34) = ALGEBRAIC(:,290);
    ALGEBRAIC(:,106) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,218) = ALGEBRAIC(:,176)+ CONSTANTS(:,197).*CONSTANTS(:,201).*ALGEBRAIC(:,106);
    ALGEBRAIC(:,281) = ALGEBRAIC(:,141)+ CONSTANTS(:,198).*CONSTANTS(:,201).*ALGEBRAIC(:,106);
    ALGEBRAIC(:,286) =  CONSTANTS(:,90).*(exp(ALGEBRAIC(:,218)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,281)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,293) = ALGEBRAIC(:,286) - ALGEBRAIC(:,228);
    RATES(:,66) = ALGEBRAIC(:,293);
    ALGEBRAIC(:,294) =  - ALGEBRAIC(:,286)+ALGEBRAIC(:,274);
    RATES(:,71) = ALGEBRAIC(:,294);
    ALGEBRAIC(:,295) =  CONSTANTS(:,201).*(  - CONSTANTS(:,197).*ALGEBRAIC(:,286)+ CONSTANTS(:,198).*ALGEBRAIC(:,286));
    RATES(:,86) = ALGEBRAIC(:,295);
    ALGEBRAIC(:,107) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,142) =  CONSTANTS(:,169).*CONSTANTS(:,201).*ALGEBRAIC(:,107);
    ALGEBRAIC(:,114) =  CONSTANTS(:,271).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,219) =  CONSTANTS(:,271).*log( CONSTANTS(:,21).*STATES(:,98));
    ALGEBRAIC(:,224) = ALGEBRAIC(:,114)+ALGEBRAIC(:,142)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,121) =  CONSTANTS(:,271).*log( CONSTANTS(:,60).*ALGEBRAIC(:,50));
    ALGEBRAIC(:,229) = ALGEBRAIC(:,121)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,247) = piecewise({ALGEBRAIC(:,142)==0.000000,  CONSTANTS(:,98).*(exp(ALGEBRAIC(:,224)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,229)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,98).*ALGEBRAIC(:,142))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,142)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,224)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,229)./CONSTANTS(:,271))));
    ALGEBRAIC(:,263) =  CONSTANTS(:,271).*log( CONSTANTS(:,26).*STATES(:,99));
    ALGEBRAIC(:,270) = ALGEBRAIC(:,114)+ALGEBRAIC(:,142)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,275) = ALGEBRAIC(:,121)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,296) = piecewise({ALGEBRAIC(:,142)==0.000000,  CONSTANTS(:,99).*(exp(ALGEBRAIC(:,270)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,275)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,99).*ALGEBRAIC(:,142))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,142)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,270)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,275)./CONSTANTS(:,271))));
    ALGEBRAIC(:,300) = ALGEBRAIC(:,296)+ALGEBRAIC(:,247);
    RATES(:,27) = ALGEBRAIC(:,300);
    ALGEBRAIC(:,188) = ALGEBRAIC(:,137)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,11) = CONSTANTS(:,247)+STATES(:,37);
    ALGEBRAIC(:,151) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,35).*ALGEBRAIC(:,11));
    ALGEBRAIC(:,254) = ALGEBRAIC(:,151)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,260) =  CONSTANTS(:,105).*(exp(ALGEBRAIC(:,188)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,254)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,211) = ALGEBRAIC(:,137)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,291) = ALGEBRAIC(:,144)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,298) =  CONSTANTS(:,144).*(exp(ALGEBRAIC(:,211)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,291)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,303) = (ALGEBRAIC(:,237) - ALGEBRAIC(:,260)) - ALGEBRAIC(:,298);
    RATES(:,35) = ALGEBRAIC(:,303);
    ALGEBRAIC(:,201) = ALGEBRAIC(:,144)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,12) = CONSTANTS(:,248)+STATES(:,38);
    ALGEBRAIC(:,158) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,38).*ALGEBRAIC(:,12));
    ALGEBRAIC(:,265) = ALGEBRAIC(:,158)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,272) =  CONSTANTS(:,106).*(exp(ALGEBRAIC(:,201)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,265)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,304) = (ALGEBRAIC(:,249) - ALGEBRAIC(:,272))+ALGEBRAIC(:,298);
    RATES(:,36) = ALGEBRAIC(:,304);
    ALGEBRAIC(:,149) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,107);
    ALGEBRAIC(:,128) =  CONSTANTS(:,271).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,235) = ALGEBRAIC(:,128)+ALGEBRAIC(:,149)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,135) =  CONSTANTS(:,271).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,240) = ALGEBRAIC(:,135)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,252) = piecewise({ALGEBRAIC(:,149)==0.000000,  CONSTANTS(:,100).*(exp(ALGEBRAIC(:,235)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,240)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,100).*ALGEBRAIC(:,149))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,149)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,235)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,240)./CONSTANTS(:,271))));
    ALGEBRAIC(:,282) = ALGEBRAIC(:,128)+ALGEBRAIC(:,149)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,287) = ALGEBRAIC(:,135)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,301) = piecewise({ALGEBRAIC(:,149)==0.000000,  CONSTANTS(:,101).*(exp(ALGEBRAIC(:,282)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,287)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,101).*ALGEBRAIC(:,149))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,149)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,282)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,287)./CONSTANTS(:,271))));
    ALGEBRAIC(:,307) =  - ALGEBRAIC(:,252) - ALGEBRAIC(:,301);
    RATES(:,29) = ALGEBRAIC(:,307);
    ALGEBRAIC(:,308) = ALGEBRAIC(:,301)+ALGEBRAIC(:,252);
    RATES(:,30) = ALGEBRAIC(:,308);
    ALGEBRAIC(:,216) = ALGEBRAIC(:,151)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,305) = ALGEBRAIC(:,158)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,311) =  CONSTANTS(:,145).*(exp(ALGEBRAIC(:,216)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,305)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,315) = ALGEBRAIC(:,260) - ALGEBRAIC(:,311);
    RATES(:,37) = ALGEBRAIC(:,315);
    ALGEBRAIC(:,221) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,109) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,116) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,165) = ALGEBRAIC(:,116)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,102)+ALGEBRAIC(:,158)+ CONSTANTS(:,166).*ALGEBRAIC(:,109);
    ALGEBRAIC(:,226) = ALGEBRAIC(:,109)+ALGEBRAIC(:,158)+ CONSTANTS(:,166).*ALGEBRAIC(:,109);
    ALGEBRAIC(:,316) = piecewise({ALGEBRAIC(:,221)==0.000000,  CONSTANTS(:,95).*(exp(ALGEBRAIC(:,165)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,226)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,95).*ALGEBRAIC(:,221))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,221)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,165)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,226)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,320) = ALGEBRAIC(:,316) -  CONSTANTS(:,166).*(ALGEBRAIC(:,316) - ALGEBRAIC(:,316));
    RATES(:,31) = ALGEBRAIC(:,320);
    ALGEBRAIC(:,321) =  - ALGEBRAIC(:,316);
    RATES(:,32) = ALGEBRAIC(:,321);
    ALGEBRAIC(:,322) = (ALGEBRAIC(:,272)+ALGEBRAIC(:,311)) - (ALGEBRAIC(:,316) - ALGEBRAIC(:,316));
    RATES(:,38) = ALGEBRAIC(:,322);
    ALGEBRAIC(:,323) =  CONSTANTS(:,201).*((((((((((((((  - CONSTANTS(:,172).*ALGEBRAIC(:,316)+ CONSTANTS(:,188).*ALGEBRAIC(:,298)) -  CONSTANTS(:,176).*ALGEBRAIC(:,298))+ CONSTANTS(:,188).*ALGEBRAIC(:,284)) -  CONSTANTS(:,176).*ALGEBRAIC(:,284))+ CONSTANTS(:,187).*ALGEBRAIC(:,260)) -  CONSTANTS(:,175).*ALGEBRAIC(:,260))+ CONSTANTS(:,187).*ALGEBRAIC(:,237)) -  CONSTANTS(:,175).*ALGEBRAIC(:,237))+ CONSTANTS(:,188).*ALGEBRAIC(:,311)) -  CONSTANTS(:,176).*ALGEBRAIC(:,311))+ CONSTANTS(:,187).*ALGEBRAIC(:,272)) -  CONSTANTS(:,175).*ALGEBRAIC(:,272))+ CONSTANTS(:,187).*ALGEBRAIC(:,249)) -  CONSTANTS(:,175).*ALGEBRAIC(:,249));
    RATES(:,80) = ALGEBRAIC(:,323);
    ALGEBRAIC(:,156) =  CONSTANTS(:,271).*log( CONSTANTS(:,1).*STATES(:,88));
    ALGEBRAIC(:,163) =  CONSTANTS(:,271).*log( CONSTANTS(:,3).*STATES(:,94));
    ALGEBRAIC(:,309) =  CONSTANTS(:,127).*(exp(ALGEBRAIC(:,156)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,163)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,170) =  CONSTANTS(:,271).*log( CONSTANTS(:,6).*STATES(:,89));
    ALGEBRAIC(:,177) =  CONSTANTS(:,271).*log( CONSTANTS(:,8).*STATES(:,95));
    ALGEBRAIC(:,313) =  CONSTANTS(:,128).*(exp(ALGEBRAIC(:,170)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,186) =  CONSTANTS(:,271).*log( CONSTANTS(:,11).*STATES(:,90));
    ALGEBRAIC(:,199) =  CONSTANTS(:,271).*log( CONSTANTS(:,12).*STATES(:,96));
    ALGEBRAIC(:,318) =  CONSTANTS(:,129).*(exp(ALGEBRAIC(:,186)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,204) =  CONSTANTS(:,271).*log( CONSTANTS(:,13).*STATES(:,91));
    ALGEBRAIC(:,209) =  CONSTANTS(:,271).*log( CONSTANTS(:,15).*STATES(:,97));
    ALGEBRAIC(:,325) =  CONSTANTS(:,130).*(exp(ALGEBRAIC(:,204)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,209)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,214) =  CONSTANTS(:,271).*log( CONSTANTS(:,19).*STATES(:,92));
    ALGEBRAIC(:,328) =  CONSTANTS(:,131).*(exp(ALGEBRAIC(:,214)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,258) =  CONSTANTS(:,271).*log( CONSTANTS(:,25).*STATES(:,93));
    ALGEBRAIC(:,331) =  CONSTANTS(:,132).*(exp(ALGEBRAIC(:,258)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,334) =  CONSTANTS(:,169).*(ALGEBRAIC(:,325)+ALGEBRAIC(:,328)+ALGEBRAIC(:,318)+ALGEBRAIC(:,313)+ALGEBRAIC(:,309)+ALGEBRAIC(:,331));
    ALGEBRAIC(:,338) = (ALGEBRAIC(:,334) - ALGEBRAIC(:,247)) - ALGEBRAIC(:,296);
    RATES(:,28) = ALGEBRAIC(:,338);
    ALGEBRAIC(:,73) = CONSTANTS(:,227)+STATES(:,50);
    ALGEBRAIC(:,197) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,32).*ALGEBRAIC(:,73));
    ALGEBRAIC(:,261) = ALGEBRAIC(:,197);
    ALGEBRAIC(:,119) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,76) = CONSTANTS(:,228)+STATES(:,51);
    ALGEBRAIC(:,202) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,40).*ALGEBRAIC(:,76));
    ALGEBRAIC(:,341) = ALGEBRAIC(:,119)+ALGEBRAIC(:,202);
    ALGEBRAIC(:,344) =  CONSTANTS(:,81).*(exp(ALGEBRAIC(:,261)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,341)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,306) = ALGEBRAIC(:,202);
    ALGEBRAIC(:,83) = CONSTANTS(:,229)+STATES(:,52);
    ALGEBRAIC(:,207) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,46).*ALGEBRAIC(:,83));
    ALGEBRAIC(:,354) = ALGEBRAIC(:,207)+ALGEBRAIC(:,119);
    ALGEBRAIC(:,358) =  CONSTANTS(:,83).*(exp(ALGEBRAIC(:,306)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,354)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,361) = ALGEBRAIC(:,344)+ALGEBRAIC(:,358);
    RATES(:,40) = ALGEBRAIC(:,361);
    ALGEBRAIC(:,362) =  - ALGEBRAIC(:,358)+ALGEBRAIC(:,344);
    RATES(:,51) = ALGEBRAIC(:,362);
    ALGEBRAIC(:,87) = CONSTANTS(:,233)+STATES(:,56);
    ALGEBRAIC(:,227) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,18).*ALGEBRAIC(:,87));
    ALGEBRAIC(:,266) = ALGEBRAIC(:,227);
    ALGEBRAIC(:,126) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,88) = CONSTANTS(:,234)+STATES(:,57);
    ALGEBRAIC(:,232) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,24).*ALGEBRAIC(:,88));
    ALGEBRAIC(:,347) = ALGEBRAIC(:,126)+ALGEBRAIC(:,232);
    ALGEBRAIC(:,350) =  CONSTANTS(:,74).*(exp(ALGEBRAIC(:,266)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,347)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,112) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,273) = ALGEBRAIC(:,232)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,89) = CONSTANTS(:,235)+STATES(:,58);
    ALGEBRAIC(:,238) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,27).*ALGEBRAIC(:,89));
    ALGEBRAIC(:,353) = ALGEBRAIC(:,238);
    ALGEBRAIC(:,357) =  CONSTANTS(:,75).*(exp(ALGEBRAIC(:,273)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,353)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,363) = ALGEBRAIC(:,350) - ALGEBRAIC(:,357);
    RATES(:,57) = ALGEBRAIC(:,363);
    ALGEBRAIC(:,355) =  CONSTANTS(:,115).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,170)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,359) =  CONSTANTS(:,119).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,186)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,335) =  CONSTANTS(:,109).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,204)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,367) = (( - ALGEBRAIC(:,335) - ALGEBRAIC(:,355)) - ALGEBRAIC(:,359)) - ALGEBRAIC(:,309);
    RATES(:,88) = ALGEBRAIC(:,367);
    ALGEBRAIC(:,366) =  CONSTANTS(:,123).*(exp((ALGEBRAIC(:,170)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,186)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,342) =  CONSTANTS(:,113).*(exp((ALGEBRAIC(:,186)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,372) = ( - ALGEBRAIC(:,342)+ALGEBRAIC(:,366)+ALGEBRAIC(:,359)) - ALGEBRAIC(:,318);
    RATES(:,90) = ALGEBRAIC(:,372);
    ALGEBRAIC(:,278) = ALGEBRAIC(:,238)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,90) = CONSTANTS(:,236)+STATES(:,59);
    ALGEBRAIC(:,243) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,28).*ALGEBRAIC(:,90));
    ALGEBRAIC(:,364) = ALGEBRAIC(:,243);
    ALGEBRAIC(:,369) =  CONSTANTS(:,76).*(exp(ALGEBRAIC(:,278)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,364)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,374) =  - ALGEBRAIC(:,357) - ALGEBRAIC(:,369);
    RATES(:,39) = ALGEBRAIC(:,374);
    ALGEBRAIC(:,133) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,312) = ALGEBRAIC(:,207)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,84) = CONSTANTS(:,230)+STATES(:,53);
    ALGEBRAIC(:,212) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,48).*ALGEBRAIC(:,84));
    ALGEBRAIC(:,365) = ALGEBRAIC(:,212);
    ALGEBRAIC(:,370) =  CONSTANTS(:,85).*(exp(ALGEBRAIC(:,312)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,365)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,375) = ALGEBRAIC(:,358) - ALGEBRAIC(:,370);
    RATES(:,52) = ALGEBRAIC(:,375);
    ALGEBRAIC(:,376) =  - ALGEBRAIC(:,369)+ALGEBRAIC(:,357);
    RATES(:,58) = ALGEBRAIC(:,376);
    ALGEBRAIC(:,371) =  CONSTANTS(:,117).*(exp((ALGEBRAIC(:,204)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,214)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,339) =  CONSTANTS(:,111).*(exp((ALGEBRAIC(:,170)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,214)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,380) = (( - ALGEBRAIC(:,339) - ALGEBRAIC(:,366))+ALGEBRAIC(:,371)) - ALGEBRAIC(:,313);
    RATES(:,89) = ALGEBRAIC(:,380);
    ALGEBRAIC(:,379) =  CONSTANTS(:,121).*(exp((ALGEBRAIC(:,204)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,385) = (( - ALGEBRAIC(:,379)+ALGEBRAIC(:,335)) - ALGEBRAIC(:,371)) - ALGEBRAIC(:,325);
    RATES(:,91) = ALGEBRAIC(:,385);
    ALGEBRAIC(:,285) = ALGEBRAIC(:,243);
    ALGEBRAIC(:,54) = CONSTANTS(:,220)+STATES(:,43);
    ALGEBRAIC(:,140) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,62).*ALGEBRAIC(:,54));
    ALGEBRAIC(:,64) = CONSTANTS(:,224)+STATES(:,47);
    ALGEBRAIC(:,168) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,71).*ALGEBRAIC(:,64));
    ALGEBRAIC(:,67) = CONSTANTS(:,225)+STATES(:,48);
    ALGEBRAIC(:,175) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,29).*ALGEBRAIC(:,67));
    ALGEBRAIC(:,377) = ALGEBRAIC(:,140)+ALGEBRAIC(:,168)+ALGEBRAIC(:,175);
    ALGEBRAIC(:,382) =  CONSTANTS(:,77).*(exp(ALGEBRAIC(:,285)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,377)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,387) = ALGEBRAIC(:,382);
    RATES(:,43) = ALGEBRAIC(:,387);
    ALGEBRAIC(:,388) = ALGEBRAIC(:,382);
    RATES(:,47) = ALGEBRAIC(:,388);
    ALGEBRAIC(:,317) = ALGEBRAIC(:,212)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,85) = CONSTANTS(:,231)+STATES(:,54);
    ALGEBRAIC(:,217) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,50).*ALGEBRAIC(:,85));
    ALGEBRAIC(:,378) = ALGEBRAIC(:,217);
    ALGEBRAIC(:,383) =  CONSTANTS(:,87).*(exp(ALGEBRAIC(:,317)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,378)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,389) = ALGEBRAIC(:,370) - ALGEBRAIC(:,383);
    RATES(:,53) = ALGEBRAIC(:,389);
    ALGEBRAIC(:,390) = ALGEBRAIC(:,369) - ALGEBRAIC(:,382);
    RATES(:,59) = ALGEBRAIC(:,390);
    ALGEBRAIC(:,384) =  CONSTANTS(:,125).*(exp((ALGEBRAIC(:,214)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,394) = ((ALGEBRAIC(:,371)+ALGEBRAIC(:,339)) - ALGEBRAIC(:,328)) - ALGEBRAIC(:,384);
    RATES(:,92) = ALGEBRAIC(:,394);
    ALGEBRAIC(:,395) = ((ALGEBRAIC(:,379)+ALGEBRAIC(:,342)) - ALGEBRAIC(:,331))+ALGEBRAIC(:,384);
    RATES(:,93) = ALGEBRAIC(:,395);
    ALGEBRAIC(:,324) = ALGEBRAIC(:,217)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,86) = CONSTANTS(:,232)+STATES(:,55);
    ALGEBRAIC(:,222) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,52).*ALGEBRAIC(:,86));
    ALGEBRAIC(:,105) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,392) = ALGEBRAIC(:,222)+ CONSTANTS(:,170).*ALGEBRAIC(:,105);
    ALGEBRAIC(:,398) =  CONSTANTS(:,89).*(exp(ALGEBRAIC(:,324)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,392)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,401) =  - ALGEBRAIC(:,370) - (ALGEBRAIC(:,383)+ALGEBRAIC(:,398));
    RATES(:,42) = ALGEBRAIC(:,401);
    ALGEBRAIC(:,58) = CONSTANTS(:,222)+STATES(:,45);
    ALGEBRAIC(:,154) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,66).*ALGEBRAIC(:,58));
    ALGEBRAIC(:,292) = ALGEBRAIC(:,175)+ALGEBRAIC(:,154);
    ALGEBRAIC(:,70) = CONSTANTS(:,226)+STATES(:,49);
    ALGEBRAIC(:,184) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,30).*ALGEBRAIC(:,70));
    ALGEBRAIC(:,391) = ALGEBRAIC(:,184);
    ALGEBRAIC(:,397) =  CONSTANTS(:,78).*(exp(ALGEBRAIC(:,292)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,391)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,402) =  - ALGEBRAIC(:,397);
    RATES(:,45) = ALGEBRAIC(:,402);
    ALGEBRAIC(:,403) =  - ALGEBRAIC(:,397)+ALGEBRAIC(:,382);
    RATES(:,48) = ALGEBRAIC(:,403);
    ALGEBRAIC(:,404) = ALGEBRAIC(:,383) - ALGEBRAIC(:,398);
    RATES(:,54) = ALGEBRAIC(:,404);
    ALGEBRAIC(:,345) =  CONSTANTS(:,110).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,209)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,393) =  CONSTANTS(:,116).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,399) =  CONSTANTS(:,120).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,408) = (( - ALGEBRAIC(:,345) - ALGEBRAIC(:,393)) - ALGEBRAIC(:,399))+ALGEBRAIC(:,309);
    RATES(:,94) = ALGEBRAIC(:,408);
    ALGEBRAIC(:,351) =  CONSTANTS(:,114).*(exp((ALGEBRAIC(:,199)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,407) =  CONSTANTS(:,124).*(exp((ALGEBRAIC(:,177)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,413) =  - ALGEBRAIC(:,351)+ALGEBRAIC(:,407)+ALGEBRAIC(:,399)+ALGEBRAIC(:,318);
    RATES(:,96) = ALGEBRAIC(:,413);
    ALGEBRAIC(:,327) = ALGEBRAIC(:,222);
    ALGEBRAIC(:,57) = CONSTANTS(:,221)+STATES(:,44);
    ALGEBRAIC(:,147) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,65).*ALGEBRAIC(:,57));
    ALGEBRAIC(:,61) = CONSTANTS(:,223)+STATES(:,46);
    ALGEBRAIC(:,161) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,53).*ALGEBRAIC(:,61));
    ALGEBRAIC(:,406) = ALGEBRAIC(:,161)+ALGEBRAIC(:,147);
    ALGEBRAIC(:,411) =  CONSTANTS(:,91).*(exp(ALGEBRAIC(:,327)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,406)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,415) = ALGEBRAIC(:,411);
    RATES(:,44) = ALGEBRAIC(:,415);
    ALGEBRAIC(:,299) = ALGEBRAIC(:,184);
    ALGEBRAIC(:,405) = ALGEBRAIC(:,197);
    ALGEBRAIC(:,410) =  CONSTANTS(:,79).*(exp(ALGEBRAIC(:,299)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,405)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,416) = ALGEBRAIC(:,397) - ALGEBRAIC(:,410);
    RATES(:,49) = ALGEBRAIC(:,416);
    ALGEBRAIC(:,417) =  - ALGEBRAIC(:,344)+ALGEBRAIC(:,410);
    RATES(:,50) = ALGEBRAIC(:,417);
    ALGEBRAIC(:,418) = ALGEBRAIC(:,398) - ALGEBRAIC(:,411);
    RATES(:,55) = ALGEBRAIC(:,418);
    ALGEBRAIC(:,348) =  CONSTANTS(:,112).*(exp((ALGEBRAIC(:,177)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,412) =  CONSTANTS(:,118).*(exp((ALGEBRAIC(:,209)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,421) = ( - ALGEBRAIC(:,348) - ALGEBRAIC(:,407))+ALGEBRAIC(:,412)+ALGEBRAIC(:,313);
    RATES(:,95) = ALGEBRAIC(:,421);
    ALGEBRAIC(:,420) =  CONSTANTS(:,122).*(exp((ALGEBRAIC(:,209)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,425) = (( - ALGEBRAIC(:,420)+ALGEBRAIC(:,345)) - ALGEBRAIC(:,412))+ALGEBRAIC(:,325);
    RATES(:,97) = ALGEBRAIC(:,425);
    ALGEBRAIC(:,330) = ALGEBRAIC(:,161);
    ALGEBRAIC(:,91) = CONSTANTS(:,237)+STATES(:,60);
    ALGEBRAIC(:,250) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,54).*ALGEBRAIC(:,91));
    ALGEBRAIC(:,419) = ALGEBRAIC(:,250);
    ALGEBRAIC(:,423) =  CONSTANTS(:,92).*(exp(ALGEBRAIC(:,330)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,419)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,427) = ALGEBRAIC(:,411) - ALGEBRAIC(:,423);
    RATES(:,46) = ALGEBRAIC(:,427);
    ALGEBRAIC(:,424) =  CONSTANTS(:,126).*(exp((ALGEBRAIC(:,219)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,430) = (ALGEBRAIC(:,412)+ALGEBRAIC(:,348)+ALGEBRAIC(:,328)) - ALGEBRAIC(:,424);
    RATES(:,98) = ALGEBRAIC(:,430);
    ALGEBRAIC(:,431) = ALGEBRAIC(:,420)+ALGEBRAIC(:,351)+ALGEBRAIC(:,331)+ALGEBRAIC(:,424);
    RATES(:,99) = ALGEBRAIC(:,431);
    ALGEBRAIC(:,429) =  ALGEBRAIC(:,399).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,407).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,412).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,420).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,424).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,393).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,351).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,348).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,345).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,384).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,379).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,371).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,366).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,359).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,355).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,342).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,339).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,335).*(CONSTANTS(:,190) - CONSTANTS(:,178));
    ALGEBRAIC(:,434) =  CONSTANTS(:,201).*((ALGEBRAIC(:,429) -  CONSTANTS(:,169).*(ALGEBRAIC(:,247)+ALGEBRAIC(:,296))) -  CONSTANTS(:,172).*(ALGEBRAIC(:,252)+ALGEBRAIC(:,301)));
    RATES(:,84) = ALGEBRAIC(:,434);
    ALGEBRAIC(:,333) = ALGEBRAIC(:,250);
    ALGEBRAIC(:,92) = CONSTANTS(:,238)+STATES(:,61);
    ALGEBRAIC(:,255) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,55).*ALGEBRAIC(:,92));
    ALGEBRAIC(:,428) =  CONSTANTS(:,171).*ALGEBRAIC(:,105)+ALGEBRAIC(:,126)+ALGEBRAIC(:,255);
    ALGEBRAIC(:,433) =  CONSTANTS(:,93).*(exp(ALGEBRAIC(:,333)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,428)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,436) =  - ALGEBRAIC(:,433)+ALGEBRAIC(:,423);
    RATES(:,60) = ALGEBRAIC(:,436);
    ALGEBRAIC(:,438) =  CONSTANTS(:,171).*ALGEBRAIC(:,433)+ CONSTANTS(:,170).*ALGEBRAIC(:,398);
    RATES(:,85) = ALGEBRAIC(:,438);
    ALGEBRAIC(:,337) = ALGEBRAIC(:,255);
    ALGEBRAIC(:,437) = ALGEBRAIC(:,227)+ALGEBRAIC(:,126);
    ALGEBRAIC(:,440) =  CONSTANTS(:,94).*(exp(ALGEBRAIC(:,337)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,437)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,442) = ALGEBRAIC(:,433)+ALGEBRAIC(:,440)+ALGEBRAIC(:,350);
    RATES(:,41) = ALGEBRAIC(:,442);
    ALGEBRAIC(:,443) = ALGEBRAIC(:,440) - ALGEBRAIC(:,350);
    RATES(:,56) = ALGEBRAIC(:,443);
    ALGEBRAIC(:,444) = ALGEBRAIC(:,433) - ALGEBRAIC(:,440);
    RATES(:,61) = ALGEBRAIC(:,444);
    ALGEBRAIC(:,19) = CONSTANTS(:,249)+STATES(:,11);
    ALGEBRAIC(:,101) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,136) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,20) = CONSTANTS(:,250)+STATES(:,12);
    ALGEBRAIC(:,326) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,329) =  CONSTANTS(:,135).*(exp(ALGEBRAIC(:,136)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,326)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,200) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,34) = CONSTANTS(:,257)+STATES(:,19);
    ALGEBRAIC(:,400) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,409) =  CONSTANTS(:,146).*(exp(ALGEBRAIC(:,200)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,400)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,241) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,22) = CONSTANTS(:,251)+STATES(:,13);
    ALGEBRAIC(:,452) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,453) =  CONSTANTS(:,154).*(exp(ALGEBRAIC(:,241)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,452)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,454) = ( - ALGEBRAIC(:,453) - ALGEBRAIC(:,329)) - ALGEBRAIC(:,409);
    RATES(:,11) = ALGEBRAIC(:,454);
    ALGEBRAIC(:,143) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,36) = CONSTANTS(:,258)+STATES(:,20);
    ALGEBRAIC(:,332) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,336) =  CONSTANTS(:,136).*(exp(ALGEBRAIC(:,143)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,332)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,248) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,38) = CONSTANTS(:,259)+STATES(:,21);
    ALGEBRAIC(:,455) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,456) =  CONSTANTS(:,155).*(exp(ALGEBRAIC(:,248)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,455)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,457) = ( - ALGEBRAIC(:,456) - ALGEBRAIC(:,336)) -  - ALGEBRAIC(:,409);
    RATES(:,19) = ALGEBRAIC(:,457);
    ALGEBRAIC(:,205) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,414) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,422) =  CONSTANTS(:,147).*(exp(ALGEBRAIC(:,205)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,414)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,253) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,24) = CONSTANTS(:,252)+STATES(:,14);
    ALGEBRAIC(:,458) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,459) =  CONSTANTS(:,156).*(exp(ALGEBRAIC(:,253)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,458)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,460) = ( - ALGEBRAIC(:,459)+ALGEBRAIC(:,329)) - ALGEBRAIC(:,422);
    RATES(:,12) = ALGEBRAIC(:,460);
    ALGEBRAIC(:,259) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,40) = CONSTANTS(:,260)+STATES(:,22);
    ALGEBRAIC(:,461) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,462) =  CONSTANTS(:,157).*(exp(ALGEBRAIC(:,259)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,461)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,463) = ( - ALGEBRAIC(:,462)+ALGEBRAIC(:,336)) -  - ALGEBRAIC(:,422);
    RATES(:,20) = ALGEBRAIC(:,463);
    ALGEBRAIC(:,150) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,340) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,343) =  CONSTANTS(:,137).*(exp(ALGEBRAIC(:,150)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,340)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,210) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,426) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,432) =  CONSTANTS(:,148).*(exp(ALGEBRAIC(:,210)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,426)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,264) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,26) = CONSTANTS(:,253)+STATES(:,15);
    ALGEBRAIC(:,464) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,465) =  CONSTANTS(:,158).*(exp(ALGEBRAIC(:,264)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,464)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,466) = ((ALGEBRAIC(:,453) - ALGEBRAIC(:,465)) - ALGEBRAIC(:,343)) - ALGEBRAIC(:,432);
    RATES(:,13) = ALGEBRAIC(:,466);
    ALGEBRAIC(:,157) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,346) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,349) =  CONSTANTS(:,138).*(exp(ALGEBRAIC(:,157)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,346)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,271) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,42) = CONSTANTS(:,261)+STATES(:,23);
    ALGEBRAIC(:,467) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,468) =  CONSTANTS(:,159).*(exp(ALGEBRAIC(:,271)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,467)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,469) = ((ALGEBRAIC(:,456) - ALGEBRAIC(:,468)) - ALGEBRAIC(:,349)) -  - ALGEBRAIC(:,432);
    RATES(:,21) = ALGEBRAIC(:,469);
    ALGEBRAIC(:,215) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,435) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,439) =  CONSTANTS(:,149).*(exp(ALGEBRAIC(:,215)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,435)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,276) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,28) = CONSTANTS(:,254)+STATES(:,16);
    ALGEBRAIC(:,470) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,471) =  CONSTANTS(:,160).*(exp(ALGEBRAIC(:,276)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,470)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,472) = ((ALGEBRAIC(:,459) - ALGEBRAIC(:,471))+ALGEBRAIC(:,343)) - ALGEBRAIC(:,439);
    RATES(:,14) = ALGEBRAIC(:,472);
    ALGEBRAIC(:,283) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,44) = CONSTANTS(:,262)+STATES(:,24);
    ALGEBRAIC(:,473) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,474) =  CONSTANTS(:,161).*(exp(ALGEBRAIC(:,283)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,473)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,475) = ((ALGEBRAIC(:,462) - ALGEBRAIC(:,474))+ALGEBRAIC(:,349)) -  - ALGEBRAIC(:,439);
    RATES(:,22) = ALGEBRAIC(:,475);
    ALGEBRAIC(:,164) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,352) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,356) =  CONSTANTS(:,139).*(exp(ALGEBRAIC(:,164)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,352)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,220) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,441) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,445) =  CONSTANTS(:,150).*(exp(ALGEBRAIC(:,220)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,441)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,288) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,30) = CONSTANTS(:,255)+STATES(:,17);
    ALGEBRAIC(:,476) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,477) =  CONSTANTS(:,162).*(exp(ALGEBRAIC(:,288)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,476)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,478) = ((ALGEBRAIC(:,465) - ALGEBRAIC(:,477)) - ALGEBRAIC(:,356)) - ALGEBRAIC(:,445);
    RATES(:,15) = ALGEBRAIC(:,478);
    ALGEBRAIC(:,178) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,32) = CONSTANTS(:,256)+STATES(:,18);
    ALGEBRAIC(:,373) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,381) =  CONSTANTS(:,141).*(exp(ALGEBRAIC(:,178)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,373)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,230) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,46) = CONSTANTS(:,263)+STATES(:,25);
    ALGEBRAIC(:,448) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,449) =  CONSTANTS(:,152).*(exp(ALGEBRAIC(:,230)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,448)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,479) = (ALGEBRAIC(:,477) - ALGEBRAIC(:,381)) - ALGEBRAIC(:,449);
    RATES(:,17) = ALGEBRAIC(:,479);
    ALGEBRAIC(:,171) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,360) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,368) =  CONSTANTS(:,140).*(exp(ALGEBRAIC(:,171)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,360)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,297) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,480) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,481) =  CONSTANTS(:,163).*(exp(ALGEBRAIC(:,297)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,480)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,482) = ((ALGEBRAIC(:,468) - ALGEBRAIC(:,481)) - ALGEBRAIC(:,368)) -  - ALGEBRAIC(:,445);
    RATES(:,23) = ALGEBRAIC(:,482);
    ALGEBRAIC(:,187) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,48) = CONSTANTS(:,264)+STATES(:,26);
    ALGEBRAIC(:,386) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,396) =  CONSTANTS(:,142).*(exp(ALGEBRAIC(:,187)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,386)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,483) = (ALGEBRAIC(:,481) - ALGEBRAIC(:,396)) -  - ALGEBRAIC(:,449);
    RATES(:,25) = ALGEBRAIC(:,483);
    ALGEBRAIC(:,225) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,446) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,447) =  CONSTANTS(:,151).*(exp(ALGEBRAIC(:,225)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,446)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,302) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,484) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,485) =  CONSTANTS(:,164).*(exp(ALGEBRAIC(:,302)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,484)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,486) = ((ALGEBRAIC(:,471) - ALGEBRAIC(:,485))+ALGEBRAIC(:,356)) - ALGEBRAIC(:,447);
    RATES(:,16) = ALGEBRAIC(:,486);
    ALGEBRAIC(:,236) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,450) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,451) =  CONSTANTS(:,153).*(exp(ALGEBRAIC(:,236)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,450)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,487) = (ALGEBRAIC(:,485)+ALGEBRAIC(:,381)) - ALGEBRAIC(:,451);
    RATES(:,18) = ALGEBRAIC(:,487);
    ALGEBRAIC(:,310) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,488) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,489) =  CONSTANTS(:,165).*(exp(ALGEBRAIC(:,310)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,488)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,490) = ((ALGEBRAIC(:,474) - ALGEBRAIC(:,489))+ALGEBRAIC(:,368)) -  - ALGEBRAIC(:,447);
    RATES(:,24) = ALGEBRAIC(:,490);
    ALGEBRAIC(:,314) =  CONSTANTS(:,173).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,115) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,122) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48));
    ALGEBRAIC(:,129) = ALGEBRAIC(:,115)+ CONSTANTS(:,173).*CONSTANTS(:,201).*ALGEBRAIC(:,101)+ALGEBRAIC(:,122);
    ALGEBRAIC(:,108) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,319) = ALGEBRAIC(:,108)+ALGEBRAIC(:,122);
    ALGEBRAIC(:,491) = piecewise({ALGEBRAIC(:,314)==0.000000,  CONSTANTS(:,102).*(exp(ALGEBRAIC(:,129)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,319)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,102).*ALGEBRAIC(:,314))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,314)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,129)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,319)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,492) = ALGEBRAIC(:,491);
    RATES(:,9) = ALGEBRAIC(:,492);
    ALGEBRAIC(:,493) =  - ALGEBRAIC(:,491);
    RATES(:,10) = ALGEBRAIC(:,493);
    ALGEBRAIC(:,494) = (ALGEBRAIC(:,489)+ALGEBRAIC(:,396)) - (( - ALGEBRAIC(:,451)+ALGEBRAIC(:,491)) - ALGEBRAIC(:,491));
    RATES(:,26) = ALGEBRAIC(:,494);
    ALGEBRAIC(:,495) =  CONSTANTS(:,201).*((((((((((((((  - CONSTANTS(:,173).*ALGEBRAIC(:,491)+ CONSTANTS(:,196).*ALGEBRAIC(:,453)) -  CONSTANTS(:,184).*ALGEBRAIC(:,453)+ CONSTANTS(:,196).*ALGEBRAIC(:,465)) -  CONSTANTS(:,184).*ALGEBRAIC(:,465)+ CONSTANTS(:,196).*ALGEBRAIC(:,459)) -  CONSTANTS(:,184).*ALGEBRAIC(:,459)+ CONSTANTS(:,196).*ALGEBRAIC(:,471)) -  CONSTANTS(:,184).*ALGEBRAIC(:,471)+ CONSTANTS(:,196).*ALGEBRAIC(:,485)) -  CONSTANTS(:,184).*ALGEBRAIC(:,485)+ CONSTANTS(:,194).*ALGEBRAIC(:,329)) -  CONSTANTS(:,182).*ALGEBRAIC(:,329)+ CONSTANTS(:,194).*ALGEBRAIC(:,356)) -  CONSTANTS(:,182).*ALGEBRAIC(:,356)+ CONSTANTS(:,195).*ALGEBRAIC(:,432)) -  CONSTANTS(:,183).*ALGEBRAIC(:,432)+ CONSTANTS(:,195).*ALGEBRAIC(:,445)) -  CONSTANTS(:,183).*ALGEBRAIC(:,445)+ CONSTANTS(:,195).*ALGEBRAIC(:,449)) -  CONSTANTS(:,183).*ALGEBRAIC(:,449)+ CONSTANTS(:,196).*ALGEBRAIC(:,477)) -  CONSTANTS(:,184).*ALGEBRAIC(:,477)+ CONSTANTS(:,194).*ALGEBRAIC(:,343)) -  CONSTANTS(:,182).*ALGEBRAIC(:,343)+ CONSTANTS(:,194).*ALGEBRAIC(:,381) -  CONSTANTS(:,182).*ALGEBRAIC(:,381)+ CONSTANTS(:,195).*ALGEBRAIC(:,409) -  CONSTANTS(:,183).*ALGEBRAIC(:,409)+ CONSTANTS(:,196).*ALGEBRAIC(:,456) -  CONSTANTS(:,184).*ALGEBRAIC(:,456)+ CONSTANTS(:,196).*ALGEBRAIC(:,468) -  CONSTANTS(:,184).*ALGEBRAIC(:,468)+ CONSTANTS(:,196).*ALGEBRAIC(:,462) -  CONSTANTS(:,184).*ALGEBRAIC(:,462)+ CONSTANTS(:,196).*ALGEBRAIC(:,474) -  CONSTANTS(:,184).*ALGEBRAIC(:,474)+ CONSTANTS(:,196).*ALGEBRAIC(:,489) -  CONSTANTS(:,184).*ALGEBRAIC(:,489)+ CONSTANTS(:,194).*ALGEBRAIC(:,336) -  CONSTANTS(:,182).*ALGEBRAIC(:,336)+ CONSTANTS(:,194).*ALGEBRAIC(:,368) -  CONSTANTS(:,182).*ALGEBRAIC(:,368)+ CONSTANTS(:,195).*ALGEBRAIC(:,422) -  CONSTANTS(:,183).*ALGEBRAIC(:,422)+ CONSTANTS(:,195).*ALGEBRAIC(:,439) -  CONSTANTS(:,183).*ALGEBRAIC(:,439)+ CONSTANTS(:,195).*ALGEBRAIC(:,447) -  CONSTANTS(:,183).*ALGEBRAIC(:,447)+ CONSTANTS(:,195).*ALGEBRAIC(:,451) -  CONSTANTS(:,183).*ALGEBRAIC(:,451)+ CONSTANTS(:,196).*ALGEBRAIC(:,481) -  CONSTANTS(:,184).*ALGEBRAIC(:,481)+ CONSTANTS(:,194).*ALGEBRAIC(:,349) -  CONSTANTS(:,182).*ALGEBRAIC(:,349)+ CONSTANTS(:,194).*ALGEBRAIC(:,396)) -  CONSTANTS(:,182).*ALGEBRAIC(:,396));
    RATES(:,83) = ALGEBRAIC(:,495);
   RATES = RATES';
end

% Calculate algebraic variables
function ALGEBRAIC = computeAlgebraic(ALGEBRAIC, CONSTANTS, STATES, VOI)
    statesSize = size(STATES);
    statesColumnCount = statesSize(2);
    if ( statesColumnCount == 1)
        STATES = STATES';
        utilOnes = 1;
    else
        statesRowCount = statesSize(1);
        utilOnes = ones(statesRowCount, 1);
    end
    ALGEBRAIC(:,1) = VOI -  floor(VOI./CONSTANTS(:,265)).*CONSTANTS(:,265);
    ALGEBRAIC(:,4) = piecewise({ALGEBRAIC(:,1)>=0.300000&ALGEBRAIC(:,1)<=0.300000+CONSTANTS(:,266), ( 0.0300000.*CONSTANTS(:,202))./CONSTANTS(:,266) }, 0.000000);
    ALGEBRAIC(:,6) =  (1.00000./CONSTANTS(:,201)).*ALGEBRAIC(:,4);
    ALGEBRAIC(:,53) = CONSTANTS(:,212)+STATES(:,75);
    ALGEBRAIC(:,59) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,72).*ALGEBRAIC(:,53));
    ALGEBRAIC(:,51) = CONSTANTS(:,204)+STATES(:,28)+STATES(:,63)+STATES(:,74)+STATES(:,77);
    ALGEBRAIC(:,65) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,68) = ALGEBRAIC(:,65)+ALGEBRAIC(:,59);
    ALGEBRAIC(:,56) = CONSTANTS(:,213)+STATES(:,76);
    ALGEBRAIC(:,62) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,73).*ALGEBRAIC(:,56));
    ALGEBRAIC(:,71) = ALGEBRAIC(:,62);
    ALGEBRAIC(:,74) =  CONSTANTS(:,107).*(exp(ALGEBRAIC(:,68)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,71)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,77) =  - ALGEBRAIC(:,74);
    ALGEBRAIC(:,78) = ALGEBRAIC(:,74);
    ALGEBRAIC(:,79) =  - ALGEBRAIC(:,74);
    ALGEBRAIC(:,52) = CONSTANTS(:,210)+STATES(:,72);
    ALGEBRAIC(:,60) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,56).*ALGEBRAIC(:,52));
    ALGEBRAIC(:,66) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,69) = ALGEBRAIC(:,66)+ALGEBRAIC(:,60);
    ALGEBRAIC(:,55) = CONSTANTS(:,211)+STATES(:,73);
    ALGEBRAIC(:,63) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,57).*ALGEBRAIC(:,55));
    ALGEBRAIC(:,72) = ALGEBRAIC(:,63);
    ALGEBRAIC(:,75) =  CONSTANTS(:,108).*(exp(ALGEBRAIC(:,69)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,72)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,80) =  - ALGEBRAIC(:,75);
    ALGEBRAIC(:,81) = ALGEBRAIC(:,75);
    ALGEBRAIC(:,82) =  - ALGEBRAIC(:,75);
    ALGEBRAIC(:,13) = CONSTANTS(:,241)+STATES(:,3);
    ALGEBRAIC(:,124) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,58).*ALGEBRAIC(:,13));
    ALGEBRAIC(:,99) = CONSTANTS(:,209)+STATES(:,80)+STATES(:,81)+STATES(:,82)+STATES(:,83)+STATES(:,84)+STATES(:,85)+STATES(:,86)+STATES(:,87);
    ALGEBRAIC(:,103) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,145) = ALGEBRAIC(:,124)+ CONSTANTS(:,174).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,14) = CONSTANTS(:,242)+STATES(:,4);
    ALGEBRAIC(:,131) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,69).*ALGEBRAIC(:,14));
    ALGEBRAIC(:,166) = ALGEBRAIC(:,131)+ CONSTANTS(:,186).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,173) =  CONSTANTS(:,133).*(exp(ALGEBRAIC(:,145)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,166)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,180) =  - ALGEBRAIC(:,173);
    ALGEBRAIC(:,15) = CONSTANTS(:,239)+STATES(:,7);
    ALGEBRAIC(:,125) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,59).*ALGEBRAIC(:,15));
    ALGEBRAIC(:,104) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,146) = ALGEBRAIC(:,125)+ CONSTANTS(:,177).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,16) = CONSTANTS(:,240)+STATES(:,8);
    ALGEBRAIC(:,132) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,70).*ALGEBRAIC(:,16));
    ALGEBRAIC(:,167) = ALGEBRAIC(:,132)+ CONSTANTS(:,189).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,174) =  CONSTANTS(:,134).*(exp(ALGEBRAIC(:,146)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,167)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,182) =  - ALGEBRAIC(:,174);
    ALGEBRAIC(:,152) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,103);
    ALGEBRAIC(:,2) = CONSTANTS(:,205)+STATES(:,31)+STATES(:,1)+STATES(:,5)+STATES(:,30)+STATES(:,39)+STATES(:,78);
    ALGEBRAIC(:,110) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,5) = CONSTANTS(:,206)+STATES(:,32)+STATES(:,2)+STATES(:,6)+STATES(:,29)+STATES(:,40)+STATES(:,79);
    ALGEBRAIC(:,117) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,138) = ALGEBRAIC(:,117)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,103)+ALGEBRAIC(:,131)+ CONSTANTS(:,166).*ALGEBRAIC(:,110);
    ALGEBRAIC(:,159) = ALGEBRAIC(:,110)+ALGEBRAIC(:,131)+ CONSTANTS(:,166).*ALGEBRAIC(:,110);
    ALGEBRAIC(:,181) = piecewise({ALGEBRAIC(:,152)==0.000000,  CONSTANTS(:,96).*(exp(ALGEBRAIC(:,138)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,159)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,96).*ALGEBRAIC(:,152))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,152)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,138)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,159)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,189) = ALGEBRAIC(:,181) -  CONSTANTS(:,166).*(ALGEBRAIC(:,181) - ALGEBRAIC(:,181));
    ALGEBRAIC(:,190) =  - ALGEBRAIC(:,181);
    ALGEBRAIC(:,191) = ALGEBRAIC(:,173) - (ALGEBRAIC(:,181) - ALGEBRAIC(:,181));
    ALGEBRAIC(:,192) =  CONSTANTS(:,201).*((  - CONSTANTS(:,172).*ALGEBRAIC(:,181)+ CONSTANTS(:,186).*ALGEBRAIC(:,173)) -  CONSTANTS(:,174).*ALGEBRAIC(:,173));
    ALGEBRAIC(:,153) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,104);
    ALGEBRAIC(:,118) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,139) = ALGEBRAIC(:,118)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,104)+ALGEBRAIC(:,132);
    ALGEBRAIC(:,111) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,160) = ALGEBRAIC(:,111)+ALGEBRAIC(:,132);
    ALGEBRAIC(:,183) = piecewise({ALGEBRAIC(:,153)==0.000000,  CONSTANTS(:,97).*(exp(ALGEBRAIC(:,139)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,160)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,97).*ALGEBRAIC(:,153))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,153)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,139)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,160)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,193) = ALGEBRAIC(:,183);
    ALGEBRAIC(:,194) =  - ALGEBRAIC(:,183);
    ALGEBRAIC(:,195) = ALGEBRAIC(:,174) - (ALGEBRAIC(:,183) - ALGEBRAIC(:,183));
    ALGEBRAIC(:,196) =  CONSTANTS(:,201).*((  - CONSTANTS(:,172).*ALGEBRAIC(:,183)+ CONSTANTS(:,189).*ALGEBRAIC(:,174)) -  CONSTANTS(:,177).*ALGEBRAIC(:,174));
    ALGEBRAIC(:,93) = CONSTANTS(:,214)+STATES(:,66);
    ALGEBRAIC(:,141) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,31).*ALGEBRAIC(:,93));
    ALGEBRAIC(:,185) = ALGEBRAIC(:,141);
    ALGEBRAIC(:,18) = CONSTANTS(:,208)+STATES(:,10)+STATES(:,42)+STATES(:,65);
    ALGEBRAIC(:,134) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,94) = CONSTANTS(:,215)+STATES(:,67);
    ALGEBRAIC(:,148) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,39).*ALGEBRAIC(:,94));
    ALGEBRAIC(:,223) =  CONSTANTS(:,168).*ALGEBRAIC(:,134)+ALGEBRAIC(:,148);
    ALGEBRAIC(:,228) =  CONSTANTS(:,80).*(exp(ALGEBRAIC(:,185)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,223)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,233) =  CONSTANTS(:,168).*ALGEBRAIC(:,228);
    ALGEBRAIC(:,120) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,198) = ALGEBRAIC(:,148)+ALGEBRAIC(:,120);
    ALGEBRAIC(:,95) = CONSTANTS(:,216)+STATES(:,68);
    ALGEBRAIC(:,155) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,45).*ALGEBRAIC(:,95));
    ALGEBRAIC(:,234) = ALGEBRAIC(:,155);
    ALGEBRAIC(:,239) =  CONSTANTS(:,82).*(exp(ALGEBRAIC(:,198)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,234)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,244) =  - ALGEBRAIC(:,239);
    ALGEBRAIC(:,245) = ALGEBRAIC(:,228) - ALGEBRAIC(:,239);
    ALGEBRAIC(:,203) = ALGEBRAIC(:,155);
    ALGEBRAIC(:,96) = CONSTANTS(:,217)+STATES(:,69);
    ALGEBRAIC(:,162) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,47).*ALGEBRAIC(:,96));
    ALGEBRAIC(:,246) = ALGEBRAIC(:,162);
    ALGEBRAIC(:,251) =  CONSTANTS(:,84).*(exp(ALGEBRAIC(:,203)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,246)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,256) = ALGEBRAIC(:,239) - ALGEBRAIC(:,251);
    ALGEBRAIC(:,208) = ALGEBRAIC(:,162);
    ALGEBRAIC(:,50) = CONSTANTS(:,203)+STATES(:,27)+STATES(:,62);
    ALGEBRAIC(:,113) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,60).*ALGEBRAIC(:,50));
    ALGEBRAIC(:,97) = CONSTANTS(:,218)+STATES(:,70);
    ALGEBRAIC(:,169) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,49).*ALGEBRAIC(:,97));
    ALGEBRAIC(:,257) = ALGEBRAIC(:,169)+ALGEBRAIC(:,113);
    ALGEBRAIC(:,262) =  CONSTANTS(:,86).*(exp(ALGEBRAIC(:,208)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,257)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,267) = ALGEBRAIC(:,262);
    ALGEBRAIC(:,268) =  - ALGEBRAIC(:,262)+ALGEBRAIC(:,251);
    ALGEBRAIC(:,17) = CONSTANTS(:,207)+STATES(:,9)+STATES(:,41)+STATES(:,64);
    ALGEBRAIC(:,127) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,213) = ALGEBRAIC(:,169)+ CONSTANTS(:,167).*ALGEBRAIC(:,127);
    ALGEBRAIC(:,98) = CONSTANTS(:,219)+STATES(:,71);
    ALGEBRAIC(:,176) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,51).*ALGEBRAIC(:,98));
    ALGEBRAIC(:,269) = ALGEBRAIC(:,176);
    ALGEBRAIC(:,274) =  CONSTANTS(:,88).*(exp(ALGEBRAIC(:,213)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,269)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,279) =   - CONSTANTS(:,167).*ALGEBRAIC(:,274);
    ALGEBRAIC(:,280) =  - ALGEBRAIC(:,274)+ALGEBRAIC(:,262);
    ALGEBRAIC(:,7) = CONSTANTS(:,243)+STATES(:,33);
    ALGEBRAIC(:,123) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,5).*ALGEBRAIC(:,7));
    ALGEBRAIC(:,102) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,172) = ALGEBRAIC(:,123)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,9) = CONSTANTS(:,245)+STATES(:,35);
    ALGEBRAIC(:,137) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,17).*ALGEBRAIC(:,9));
    ALGEBRAIC(:,231) = ALGEBRAIC(:,137)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,237) =  CONSTANTS(:,103).*(exp(ALGEBRAIC(:,172)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,231)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,206) = ALGEBRAIC(:,123)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,8) = CONSTANTS(:,244)+STATES(:,34);
    ALGEBRAIC(:,130) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,10).*ALGEBRAIC(:,8));
    ALGEBRAIC(:,277) = ALGEBRAIC(:,130)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,284) =  CONSTANTS(:,143).*(exp(ALGEBRAIC(:,206)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,277)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,289) =  - ALGEBRAIC(:,237) - ALGEBRAIC(:,284);
    ALGEBRAIC(:,179) = ALGEBRAIC(:,130)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,10) = CONSTANTS(:,246)+STATES(:,36);
    ALGEBRAIC(:,144) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,23).*ALGEBRAIC(:,10));
    ALGEBRAIC(:,242) = ALGEBRAIC(:,144)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,249) =  CONSTANTS(:,104).*(exp(ALGEBRAIC(:,179)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,242)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,290) =  - ALGEBRAIC(:,249)+ALGEBRAIC(:,284);
    ALGEBRAIC(:,106) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,218) = ALGEBRAIC(:,176)+ CONSTANTS(:,197).*CONSTANTS(:,201).*ALGEBRAIC(:,106);
    ALGEBRAIC(:,281) = ALGEBRAIC(:,141)+ CONSTANTS(:,198).*CONSTANTS(:,201).*ALGEBRAIC(:,106);
    ALGEBRAIC(:,286) =  CONSTANTS(:,90).*(exp(ALGEBRAIC(:,218)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,281)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,293) = ALGEBRAIC(:,286) - ALGEBRAIC(:,228);
    ALGEBRAIC(:,294) =  - ALGEBRAIC(:,286)+ALGEBRAIC(:,274);
    ALGEBRAIC(:,295) =  CONSTANTS(:,201).*(  - CONSTANTS(:,197).*ALGEBRAIC(:,286)+ CONSTANTS(:,198).*ALGEBRAIC(:,286));
    ALGEBRAIC(:,107) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,142) =  CONSTANTS(:,169).*CONSTANTS(:,201).*ALGEBRAIC(:,107);
    ALGEBRAIC(:,114) =  CONSTANTS(:,271).*log( CONSTANTS(:,61).*ALGEBRAIC(:,51));
    ALGEBRAIC(:,219) =  CONSTANTS(:,271).*log( CONSTANTS(:,21).*STATES(:,98));
    ALGEBRAIC(:,224) = ALGEBRAIC(:,114)+ALGEBRAIC(:,142)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,121) =  CONSTANTS(:,271).*log( CONSTANTS(:,60).*ALGEBRAIC(:,50));
    ALGEBRAIC(:,229) = ALGEBRAIC(:,121)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,247) = piecewise({ALGEBRAIC(:,142)==0.000000,  CONSTANTS(:,98).*(exp(ALGEBRAIC(:,224)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,229)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,98).*ALGEBRAIC(:,142))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,142)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,224)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,229)./CONSTANTS(:,271))));
    ALGEBRAIC(:,263) =  CONSTANTS(:,271).*log( CONSTANTS(:,26).*STATES(:,99));
    ALGEBRAIC(:,270) = ALGEBRAIC(:,114)+ALGEBRAIC(:,142)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,275) = ALGEBRAIC(:,121)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,296) = piecewise({ALGEBRAIC(:,142)==0.000000,  CONSTANTS(:,99).*(exp(ALGEBRAIC(:,270)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,275)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,99).*ALGEBRAIC(:,142))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,142)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,270)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,275)./CONSTANTS(:,271))));
    ALGEBRAIC(:,300) = ALGEBRAIC(:,296)+ALGEBRAIC(:,247);
    ALGEBRAIC(:,188) = ALGEBRAIC(:,137)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,11) = CONSTANTS(:,247)+STATES(:,37);
    ALGEBRAIC(:,151) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,35).*ALGEBRAIC(:,11));
    ALGEBRAIC(:,254) = ALGEBRAIC(:,151)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,260) =  CONSTANTS(:,105).*(exp(ALGEBRAIC(:,188)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,254)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,211) = ALGEBRAIC(:,137)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,291) = ALGEBRAIC(:,144)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,298) =  CONSTANTS(:,144).*(exp(ALGEBRAIC(:,211)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,291)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,303) = (ALGEBRAIC(:,237) - ALGEBRAIC(:,260)) - ALGEBRAIC(:,298);
    ALGEBRAIC(:,201) = ALGEBRAIC(:,144)+ CONSTANTS(:,175).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,12) = CONSTANTS(:,248)+STATES(:,38);
    ALGEBRAIC(:,158) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,38).*ALGEBRAIC(:,12));
    ALGEBRAIC(:,265) = ALGEBRAIC(:,158)+ CONSTANTS(:,187).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,272) =  CONSTANTS(:,106).*(exp(ALGEBRAIC(:,201)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,265)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,304) = (ALGEBRAIC(:,249) - ALGEBRAIC(:,272))+ALGEBRAIC(:,298);
    ALGEBRAIC(:,149) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,107);
    ALGEBRAIC(:,128) =  CONSTANTS(:,271).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,235) = ALGEBRAIC(:,128)+ALGEBRAIC(:,149)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,135) =  CONSTANTS(:,271).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,240) = ALGEBRAIC(:,135)+ALGEBRAIC(:,219);
    ALGEBRAIC(:,252) = piecewise({ALGEBRAIC(:,149)==0.000000,  CONSTANTS(:,100).*(exp(ALGEBRAIC(:,235)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,240)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,100).*ALGEBRAIC(:,149))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,149)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,235)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,240)./CONSTANTS(:,271))));
    ALGEBRAIC(:,282) = ALGEBRAIC(:,128)+ALGEBRAIC(:,149)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,287) = ALGEBRAIC(:,135)+ALGEBRAIC(:,263);
    ALGEBRAIC(:,301) = piecewise({ALGEBRAIC(:,149)==0.000000,  CONSTANTS(:,101).*(exp(ALGEBRAIC(:,282)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,287)./CONSTANTS(:,271))) },  ((( CONSTANTS(:,101).*ALGEBRAIC(:,149))./CONSTANTS(:,271))./(exp(ALGEBRAIC(:,149)./CONSTANTS(:,271)) - 1.00000)).*(exp(ALGEBRAIC(:,282)./CONSTANTS(:,271)) - exp(ALGEBRAIC(:,287)./CONSTANTS(:,271))));
    ALGEBRAIC(:,307) =  - ALGEBRAIC(:,252) - ALGEBRAIC(:,301);
    ALGEBRAIC(:,308) = ALGEBRAIC(:,301)+ALGEBRAIC(:,252);
    ALGEBRAIC(:,216) = ALGEBRAIC(:,151)+ CONSTANTS(:,176).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,305) = ALGEBRAIC(:,158)+ CONSTANTS(:,188).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,311) =  CONSTANTS(:,145).*(exp(ALGEBRAIC(:,216)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,305)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,315) = ALGEBRAIC(:,260) - ALGEBRAIC(:,311);
    ALGEBRAIC(:,221) =  CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,102);
    ALGEBRAIC(:,109) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,116) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,165) = ALGEBRAIC(:,116)+ CONSTANTS(:,172).*CONSTANTS(:,201).*ALGEBRAIC(:,102)+ALGEBRAIC(:,158)+ CONSTANTS(:,166).*ALGEBRAIC(:,109);
    ALGEBRAIC(:,226) = ALGEBRAIC(:,109)+ALGEBRAIC(:,158)+ CONSTANTS(:,166).*ALGEBRAIC(:,109);
    ALGEBRAIC(:,316) = piecewise({ALGEBRAIC(:,221)==0.000000,  CONSTANTS(:,95).*(exp(ALGEBRAIC(:,165)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,226)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,95).*ALGEBRAIC(:,221))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,221)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,165)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,226)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,320) = ALGEBRAIC(:,316) -  CONSTANTS(:,166).*(ALGEBRAIC(:,316) - ALGEBRAIC(:,316));
    ALGEBRAIC(:,321) =  - ALGEBRAIC(:,316);
    ALGEBRAIC(:,322) = (ALGEBRAIC(:,272)+ALGEBRAIC(:,311)) - (ALGEBRAIC(:,316) - ALGEBRAIC(:,316));
    ALGEBRAIC(:,323) =  CONSTANTS(:,201).*((((((((((((((  - CONSTANTS(:,172).*ALGEBRAIC(:,316)+ CONSTANTS(:,188).*ALGEBRAIC(:,298)) -  CONSTANTS(:,176).*ALGEBRAIC(:,298))+ CONSTANTS(:,188).*ALGEBRAIC(:,284)) -  CONSTANTS(:,176).*ALGEBRAIC(:,284))+ CONSTANTS(:,187).*ALGEBRAIC(:,260)) -  CONSTANTS(:,175).*ALGEBRAIC(:,260))+ CONSTANTS(:,187).*ALGEBRAIC(:,237)) -  CONSTANTS(:,175).*ALGEBRAIC(:,237))+ CONSTANTS(:,188).*ALGEBRAIC(:,311)) -  CONSTANTS(:,176).*ALGEBRAIC(:,311))+ CONSTANTS(:,187).*ALGEBRAIC(:,272)) -  CONSTANTS(:,175).*ALGEBRAIC(:,272))+ CONSTANTS(:,187).*ALGEBRAIC(:,249)) -  CONSTANTS(:,175).*ALGEBRAIC(:,249));
    ALGEBRAIC(:,156) =  CONSTANTS(:,271).*log( CONSTANTS(:,1).*STATES(:,88));
    ALGEBRAIC(:,163) =  CONSTANTS(:,271).*log( CONSTANTS(:,3).*STATES(:,94));
    ALGEBRAIC(:,309) =  CONSTANTS(:,127).*(exp(ALGEBRAIC(:,156)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,163)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,170) =  CONSTANTS(:,271).*log( CONSTANTS(:,6).*STATES(:,89));
    ALGEBRAIC(:,177) =  CONSTANTS(:,271).*log( CONSTANTS(:,8).*STATES(:,95));
    ALGEBRAIC(:,313) =  CONSTANTS(:,128).*(exp(ALGEBRAIC(:,170)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,186) =  CONSTANTS(:,271).*log( CONSTANTS(:,11).*STATES(:,90));
    ALGEBRAIC(:,199) =  CONSTANTS(:,271).*log( CONSTANTS(:,12).*STATES(:,96));
    ALGEBRAIC(:,318) =  CONSTANTS(:,129).*(exp(ALGEBRAIC(:,186)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,204) =  CONSTANTS(:,271).*log( CONSTANTS(:,13).*STATES(:,91));
    ALGEBRAIC(:,209) =  CONSTANTS(:,271).*log( CONSTANTS(:,15).*STATES(:,97));
    ALGEBRAIC(:,325) =  CONSTANTS(:,130).*(exp(ALGEBRAIC(:,204)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,209)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,214) =  CONSTANTS(:,271).*log( CONSTANTS(:,19).*STATES(:,92));
    ALGEBRAIC(:,328) =  CONSTANTS(:,131).*(exp(ALGEBRAIC(:,214)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,258) =  CONSTANTS(:,271).*log( CONSTANTS(:,25).*STATES(:,93));
    ALGEBRAIC(:,331) =  CONSTANTS(:,132).*(exp(ALGEBRAIC(:,258)./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,185).*ALGEBRAIC(:,114))./CONSTANTS(:,271)));
    ALGEBRAIC(:,334) =  CONSTANTS(:,169).*(ALGEBRAIC(:,325)+ALGEBRAIC(:,328)+ALGEBRAIC(:,318)+ALGEBRAIC(:,313)+ALGEBRAIC(:,309)+ALGEBRAIC(:,331));
    ALGEBRAIC(:,338) = (ALGEBRAIC(:,334) - ALGEBRAIC(:,247)) - ALGEBRAIC(:,296);
    ALGEBRAIC(:,73) = CONSTANTS(:,227)+STATES(:,50);
    ALGEBRAIC(:,197) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,32).*ALGEBRAIC(:,73));
    ALGEBRAIC(:,261) = ALGEBRAIC(:,197);
    ALGEBRAIC(:,119) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,64).*ALGEBRAIC(:,5));
    ALGEBRAIC(:,76) = CONSTANTS(:,228)+STATES(:,51);
    ALGEBRAIC(:,202) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,40).*ALGEBRAIC(:,76));
    ALGEBRAIC(:,341) = ALGEBRAIC(:,119)+ALGEBRAIC(:,202);
    ALGEBRAIC(:,344) =  CONSTANTS(:,81).*(exp(ALGEBRAIC(:,261)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,341)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,306) = ALGEBRAIC(:,202);
    ALGEBRAIC(:,83) = CONSTANTS(:,229)+STATES(:,52);
    ALGEBRAIC(:,207) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,46).*ALGEBRAIC(:,83));
    ALGEBRAIC(:,354) = ALGEBRAIC(:,207)+ALGEBRAIC(:,119);
    ALGEBRAIC(:,358) =  CONSTANTS(:,83).*(exp(ALGEBRAIC(:,306)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,354)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,361) = ALGEBRAIC(:,344)+ALGEBRAIC(:,358);
    ALGEBRAIC(:,362) =  - ALGEBRAIC(:,358)+ALGEBRAIC(:,344);
    ALGEBRAIC(:,87) = CONSTANTS(:,233)+STATES(:,56);
    ALGEBRAIC(:,227) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,18).*ALGEBRAIC(:,87));
    ALGEBRAIC(:,266) = ALGEBRAIC(:,227);
    ALGEBRAIC(:,126) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,88) = CONSTANTS(:,234)+STATES(:,57);
    ALGEBRAIC(:,232) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,24).*ALGEBRAIC(:,88));
    ALGEBRAIC(:,347) = ALGEBRAIC(:,126)+ALGEBRAIC(:,232);
    ALGEBRAIC(:,350) =  CONSTANTS(:,74).*(exp(ALGEBRAIC(:,266)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,347)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,112) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,63).*ALGEBRAIC(:,2));
    ALGEBRAIC(:,273) = ALGEBRAIC(:,232)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,89) = CONSTANTS(:,235)+STATES(:,58);
    ALGEBRAIC(:,238) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,27).*ALGEBRAIC(:,89));
    ALGEBRAIC(:,353) = ALGEBRAIC(:,238);
    ALGEBRAIC(:,357) =  CONSTANTS(:,75).*(exp(ALGEBRAIC(:,273)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,353)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,363) = ALGEBRAIC(:,350) - ALGEBRAIC(:,357);
    ALGEBRAIC(:,355) =  CONSTANTS(:,115).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,170)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,359) =  CONSTANTS(:,119).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,186)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,335) =  CONSTANTS(:,109).*(exp((ALGEBRAIC(:,156)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,204)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,367) = (( - ALGEBRAIC(:,335) - ALGEBRAIC(:,355)) - ALGEBRAIC(:,359)) - ALGEBRAIC(:,309);
    ALGEBRAIC(:,366) =  CONSTANTS(:,123).*(exp((ALGEBRAIC(:,170)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,186)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,342) =  CONSTANTS(:,113).*(exp((ALGEBRAIC(:,186)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,372) = ( - ALGEBRAIC(:,342)+ALGEBRAIC(:,366)+ALGEBRAIC(:,359)) - ALGEBRAIC(:,318);
    ALGEBRAIC(:,278) = ALGEBRAIC(:,238)+ALGEBRAIC(:,112);
    ALGEBRAIC(:,90) = CONSTANTS(:,236)+STATES(:,59);
    ALGEBRAIC(:,243) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,28).*ALGEBRAIC(:,90));
    ALGEBRAIC(:,364) = ALGEBRAIC(:,243);
    ALGEBRAIC(:,369) =  CONSTANTS(:,76).*(exp(ALGEBRAIC(:,278)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,364)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,374) =  - ALGEBRAIC(:,357) - ALGEBRAIC(:,369);
    ALGEBRAIC(:,133) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,312) = ALGEBRAIC(:,207)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,84) = CONSTANTS(:,230)+STATES(:,53);
    ALGEBRAIC(:,212) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,48).*ALGEBRAIC(:,84));
    ALGEBRAIC(:,365) = ALGEBRAIC(:,212);
    ALGEBRAIC(:,370) =  CONSTANTS(:,85).*(exp(ALGEBRAIC(:,312)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,365)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,375) = ALGEBRAIC(:,358) - ALGEBRAIC(:,370);
    ALGEBRAIC(:,376) =  - ALGEBRAIC(:,369)+ALGEBRAIC(:,357);
    ALGEBRAIC(:,371) =  CONSTANTS(:,117).*(exp((ALGEBRAIC(:,204)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,214)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,339) =  CONSTANTS(:,111).*(exp((ALGEBRAIC(:,170)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,214)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,380) = (( - ALGEBRAIC(:,339) - ALGEBRAIC(:,366))+ALGEBRAIC(:,371)) - ALGEBRAIC(:,313);
    ALGEBRAIC(:,379) =  CONSTANTS(:,121).*(exp((ALGEBRAIC(:,204)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,385) = (( - ALGEBRAIC(:,379)+ALGEBRAIC(:,335)) - ALGEBRAIC(:,371)) - ALGEBRAIC(:,325);
    ALGEBRAIC(:,285) = ALGEBRAIC(:,243);
    ALGEBRAIC(:,54) = CONSTANTS(:,220)+STATES(:,43);
    ALGEBRAIC(:,140) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,62).*ALGEBRAIC(:,54));
    ALGEBRAIC(:,64) = CONSTANTS(:,224)+STATES(:,47);
    ALGEBRAIC(:,168) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,71).*ALGEBRAIC(:,64));
    ALGEBRAIC(:,67) = CONSTANTS(:,225)+STATES(:,48);
    ALGEBRAIC(:,175) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,29).*ALGEBRAIC(:,67));
    ALGEBRAIC(:,377) = ALGEBRAIC(:,140)+ALGEBRAIC(:,168)+ALGEBRAIC(:,175);
    ALGEBRAIC(:,382) =  CONSTANTS(:,77).*(exp(ALGEBRAIC(:,285)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,377)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,387) = ALGEBRAIC(:,382);
    ALGEBRAIC(:,388) = ALGEBRAIC(:,382);
    ALGEBRAIC(:,317) = ALGEBRAIC(:,212)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,85) = CONSTANTS(:,231)+STATES(:,54);
    ALGEBRAIC(:,217) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,50).*ALGEBRAIC(:,85));
    ALGEBRAIC(:,378) = ALGEBRAIC(:,217);
    ALGEBRAIC(:,383) =  CONSTANTS(:,87).*(exp(ALGEBRAIC(:,317)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,378)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,389) = ALGEBRAIC(:,370) - ALGEBRAIC(:,383);
    ALGEBRAIC(:,390) = ALGEBRAIC(:,369) - ALGEBRAIC(:,382);
    ALGEBRAIC(:,384) =  CONSTANTS(:,125).*(exp((ALGEBRAIC(:,214)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,258)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,394) = ((ALGEBRAIC(:,371)+ALGEBRAIC(:,339)) - ALGEBRAIC(:,328)) - ALGEBRAIC(:,384);
    ALGEBRAIC(:,395) = ((ALGEBRAIC(:,379)+ALGEBRAIC(:,342)) - ALGEBRAIC(:,331))+ALGEBRAIC(:,384);
    ALGEBRAIC(:,324) = ALGEBRAIC(:,217)+ALGEBRAIC(:,133);
    ALGEBRAIC(:,86) = CONSTANTS(:,232)+STATES(:,55);
    ALGEBRAIC(:,222) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,52).*ALGEBRAIC(:,86));
    ALGEBRAIC(:,105) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,392) = ALGEBRAIC(:,222)+ CONSTANTS(:,170).*ALGEBRAIC(:,105);
    ALGEBRAIC(:,398) =  CONSTANTS(:,89).*(exp(ALGEBRAIC(:,324)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,392)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,401) =  - ALGEBRAIC(:,370) - (ALGEBRAIC(:,383)+ALGEBRAIC(:,398));
    ALGEBRAIC(:,58) = CONSTANTS(:,222)+STATES(:,45);
    ALGEBRAIC(:,154) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,66).*ALGEBRAIC(:,58));
    ALGEBRAIC(:,292) = ALGEBRAIC(:,175)+ALGEBRAIC(:,154);
    ALGEBRAIC(:,70) = CONSTANTS(:,226)+STATES(:,49);
    ALGEBRAIC(:,184) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,30).*ALGEBRAIC(:,70));
    ALGEBRAIC(:,391) = ALGEBRAIC(:,184);
    ALGEBRAIC(:,397) =  CONSTANTS(:,78).*(exp(ALGEBRAIC(:,292)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,391)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,402) =  - ALGEBRAIC(:,397);
    ALGEBRAIC(:,403) =  - ALGEBRAIC(:,397)+ALGEBRAIC(:,382);
    ALGEBRAIC(:,404) = ALGEBRAIC(:,383) - ALGEBRAIC(:,398);
    ALGEBRAIC(:,345) =  CONSTANTS(:,110).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,209)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,393) =  CONSTANTS(:,116).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,177)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,399) =  CONSTANTS(:,120).*(exp((ALGEBRAIC(:,163)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,408) = (( - ALGEBRAIC(:,345) - ALGEBRAIC(:,393)) - ALGEBRAIC(:,399))+ALGEBRAIC(:,309);
    ALGEBRAIC(:,351) =  CONSTANTS(:,114).*(exp((ALGEBRAIC(:,199)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,407) =  CONSTANTS(:,124).*(exp((ALGEBRAIC(:,177)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,199)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,413) =  - ALGEBRAIC(:,351)+ALGEBRAIC(:,407)+ALGEBRAIC(:,399)+ALGEBRAIC(:,318);
    ALGEBRAIC(:,327) = ALGEBRAIC(:,222);
    ALGEBRAIC(:,57) = CONSTANTS(:,221)+STATES(:,44);
    ALGEBRAIC(:,147) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,65).*ALGEBRAIC(:,57));
    ALGEBRAIC(:,61) = CONSTANTS(:,223)+STATES(:,46);
    ALGEBRAIC(:,161) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,53).*ALGEBRAIC(:,61));
    ALGEBRAIC(:,406) = ALGEBRAIC(:,161)+ALGEBRAIC(:,147);
    ALGEBRAIC(:,411) =  CONSTANTS(:,91).*(exp(ALGEBRAIC(:,327)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,406)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,415) = ALGEBRAIC(:,411);
    ALGEBRAIC(:,299) = ALGEBRAIC(:,184);
    ALGEBRAIC(:,405) = ALGEBRAIC(:,197);
    ALGEBRAIC(:,410) =  CONSTANTS(:,79).*(exp(ALGEBRAIC(:,299)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,405)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,416) = ALGEBRAIC(:,397) - ALGEBRAIC(:,410);
    ALGEBRAIC(:,417) =  - ALGEBRAIC(:,344)+ALGEBRAIC(:,410);
    ALGEBRAIC(:,418) = ALGEBRAIC(:,398) - ALGEBRAIC(:,411);
    ALGEBRAIC(:,348) =  CONSTANTS(:,112).*(exp((ALGEBRAIC(:,177)+ CONSTANTS(:,178).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,190).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,412) =  CONSTANTS(:,118).*(exp((ALGEBRAIC(:,209)+ CONSTANTS(:,179).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,219)+ CONSTANTS(:,191).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,421) = ( - ALGEBRAIC(:,348) - ALGEBRAIC(:,407))+ALGEBRAIC(:,412)+ALGEBRAIC(:,313);
    ALGEBRAIC(:,420) =  CONSTANTS(:,122).*(exp((ALGEBRAIC(:,209)+ CONSTANTS(:,180).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,192).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,425) = (( - ALGEBRAIC(:,420)+ALGEBRAIC(:,345)) - ALGEBRAIC(:,412))+ALGEBRAIC(:,325);
    ALGEBRAIC(:,330) = ALGEBRAIC(:,161);
    ALGEBRAIC(:,91) = CONSTANTS(:,237)+STATES(:,60);
    ALGEBRAIC(:,250) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,54).*ALGEBRAIC(:,91));
    ALGEBRAIC(:,419) = ALGEBRAIC(:,250);
    ALGEBRAIC(:,423) =  CONSTANTS(:,92).*(exp(ALGEBRAIC(:,330)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,419)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,427) = ALGEBRAIC(:,411) - ALGEBRAIC(:,423);
    ALGEBRAIC(:,424) =  CONSTANTS(:,126).*(exp((ALGEBRAIC(:,219)+ CONSTANTS(:,181).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)) - exp((ALGEBRAIC(:,263)+ CONSTANTS(:,193).*CONSTANTS(:,201).*ALGEBRAIC(:,107))./CONSTANTS(:,271)));
    ALGEBRAIC(:,430) = (ALGEBRAIC(:,412)+ALGEBRAIC(:,348)+ALGEBRAIC(:,328)) - ALGEBRAIC(:,424);
    ALGEBRAIC(:,431) = ALGEBRAIC(:,420)+ALGEBRAIC(:,351)+ALGEBRAIC(:,331)+ALGEBRAIC(:,424);
    ALGEBRAIC(:,429) =  ALGEBRAIC(:,399).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,407).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,412).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,420).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,424).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,393).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,351).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,348).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,345).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,384).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,379).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,371).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,366).*(CONSTANTS(:,193) - CONSTANTS(:,181))+ ALGEBRAIC(:,359).*(CONSTANTS(:,192) - CONSTANTS(:,180))+ ALGEBRAIC(:,355).*(CONSTANTS(:,191) - CONSTANTS(:,179))+ ALGEBRAIC(:,342).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,339).*(CONSTANTS(:,190) - CONSTANTS(:,178))+ ALGEBRAIC(:,335).*(CONSTANTS(:,190) - CONSTANTS(:,178));
    ALGEBRAIC(:,434) =  CONSTANTS(:,201).*((ALGEBRAIC(:,429) -  CONSTANTS(:,169).*(ALGEBRAIC(:,247)+ALGEBRAIC(:,296))) -  CONSTANTS(:,172).*(ALGEBRAIC(:,252)+ALGEBRAIC(:,301)));
    ALGEBRAIC(:,333) = ALGEBRAIC(:,250);
    ALGEBRAIC(:,92) = CONSTANTS(:,238)+STATES(:,61);
    ALGEBRAIC(:,255) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,55).*ALGEBRAIC(:,92));
    ALGEBRAIC(:,428) =  CONSTANTS(:,171).*ALGEBRAIC(:,105)+ALGEBRAIC(:,126)+ALGEBRAIC(:,255);
    ALGEBRAIC(:,433) =  CONSTANTS(:,93).*(exp(ALGEBRAIC(:,333)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,428)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,436) =  - ALGEBRAIC(:,433)+ALGEBRAIC(:,423);
    ALGEBRAIC(:,438) =  CONSTANTS(:,171).*ALGEBRAIC(:,433)+ CONSTANTS(:,170).*ALGEBRAIC(:,398);
    ALGEBRAIC(:,337) = ALGEBRAIC(:,255);
    ALGEBRAIC(:,437) = ALGEBRAIC(:,227)+ALGEBRAIC(:,126);
    ALGEBRAIC(:,440) =  CONSTANTS(:,94).*(exp(ALGEBRAIC(:,337)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,437)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,442) = ALGEBRAIC(:,433)+ALGEBRAIC(:,440)+ALGEBRAIC(:,350);
    ALGEBRAIC(:,443) = ALGEBRAIC(:,440) - ALGEBRAIC(:,350);
    ALGEBRAIC(:,444) = ALGEBRAIC(:,433) - ALGEBRAIC(:,440);
    ALGEBRAIC(:,19) = CONSTANTS(:,249)+STATES(:,11);
    ALGEBRAIC(:,101) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
    ALGEBRAIC(:,136) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,20) = CONSTANTS(:,250)+STATES(:,12);
    ALGEBRAIC(:,326) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,329) =  CONSTANTS(:,135).*(exp(ALGEBRAIC(:,136)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,326)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,200) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,34) = CONSTANTS(:,257)+STATES(:,19);
    ALGEBRAIC(:,400) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,409) =  CONSTANTS(:,146).*(exp(ALGEBRAIC(:,200)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,400)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,241) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,22) = CONSTANTS(:,251)+STATES(:,13);
    ALGEBRAIC(:,452) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,453) =  CONSTANTS(:,154).*(exp(ALGEBRAIC(:,241)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,452)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,454) = ( - ALGEBRAIC(:,453) - ALGEBRAIC(:,329)) - ALGEBRAIC(:,409);
    ALGEBRAIC(:,143) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,36) = CONSTANTS(:,258)+STATES(:,20);
    ALGEBRAIC(:,332) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,336) =  CONSTANTS(:,136).*(exp(ALGEBRAIC(:,143)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,332)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,248) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,38) = CONSTANTS(:,259)+STATES(:,21);
    ALGEBRAIC(:,455) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,456) =  CONSTANTS(:,155).*(exp(ALGEBRAIC(:,248)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,455)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,457) = ( - ALGEBRAIC(:,456) - ALGEBRAIC(:,336)) -  - ALGEBRAIC(:,409);
    ALGEBRAIC(:,205) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,414) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,422) =  CONSTANTS(:,147).*(exp(ALGEBRAIC(:,205)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,414)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,253) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,24) = CONSTANTS(:,252)+STATES(:,14);
    ALGEBRAIC(:,458) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,459) =  CONSTANTS(:,156).*(exp(ALGEBRAIC(:,253)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,458)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,460) = ( - ALGEBRAIC(:,459)+ALGEBRAIC(:,329)) - ALGEBRAIC(:,422);
    ALGEBRAIC(:,259) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,40) = CONSTANTS(:,260)+STATES(:,22);
    ALGEBRAIC(:,461) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,462) =  CONSTANTS(:,157).*(exp(ALGEBRAIC(:,259)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,461)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,463) = ( - ALGEBRAIC(:,462)+ALGEBRAIC(:,336)) -  - ALGEBRAIC(:,422);
    ALGEBRAIC(:,150) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,340) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,343) =  CONSTANTS(:,137).*(exp(ALGEBRAIC(:,150)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,340)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,210) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,426) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,432) =  CONSTANTS(:,148).*(exp(ALGEBRAIC(:,210)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,426)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,264) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,26) = CONSTANTS(:,253)+STATES(:,15);
    ALGEBRAIC(:,464) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,465) =  CONSTANTS(:,158).*(exp(ALGEBRAIC(:,264)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,464)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,466) = ((ALGEBRAIC(:,453) - ALGEBRAIC(:,465)) - ALGEBRAIC(:,343)) - ALGEBRAIC(:,432);
    ALGEBRAIC(:,157) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,346) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,349) =  CONSTANTS(:,138).*(exp(ALGEBRAIC(:,157)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,346)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,271) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,42) = CONSTANTS(:,261)+STATES(:,23);
    ALGEBRAIC(:,467) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,468) =  CONSTANTS(:,159).*(exp(ALGEBRAIC(:,271)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,467)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,469) = ((ALGEBRAIC(:,456) - ALGEBRAIC(:,468)) - ALGEBRAIC(:,349)) -  - ALGEBRAIC(:,432);
    ALGEBRAIC(:,215) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,435) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,439) =  CONSTANTS(:,149).*(exp(ALGEBRAIC(:,215)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,435)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,276) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,28) = CONSTANTS(:,254)+STATES(:,16);
    ALGEBRAIC(:,470) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,471) =  CONSTANTS(:,160).*(exp(ALGEBRAIC(:,276)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,470)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,472) = ((ALGEBRAIC(:,459) - ALGEBRAIC(:,471))+ALGEBRAIC(:,343)) - ALGEBRAIC(:,439);
    ALGEBRAIC(:,283) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,44) = CONSTANTS(:,262)+STATES(:,24);
    ALGEBRAIC(:,473) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,474) =  CONSTANTS(:,161).*(exp(ALGEBRAIC(:,283)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,473)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,475) = ((ALGEBRAIC(:,462) - ALGEBRAIC(:,474))+ALGEBRAIC(:,349)) -  - ALGEBRAIC(:,439);
    ALGEBRAIC(:,164) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,352) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,356) =  CONSTANTS(:,139).*(exp(ALGEBRAIC(:,164)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,352)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,220) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,441) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,445) =  CONSTANTS(:,150).*(exp(ALGEBRAIC(:,220)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,441)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,288) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,30) = CONSTANTS(:,255)+STATES(:,17);
    ALGEBRAIC(:,476) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,477) =  CONSTANTS(:,162).*(exp(ALGEBRAIC(:,288)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,476)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,478) = ((ALGEBRAIC(:,465) - ALGEBRAIC(:,477)) - ALGEBRAIC(:,356)) - ALGEBRAIC(:,445);
    ALGEBRAIC(:,178) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,32) = CONSTANTS(:,256)+STATES(:,18);
    ALGEBRAIC(:,373) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,381) =  CONSTANTS(:,141).*(exp(ALGEBRAIC(:,178)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,373)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,230) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,46) = CONSTANTS(:,263)+STATES(:,25);
    ALGEBRAIC(:,448) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,449) =  CONSTANTS(:,152).*(exp(ALGEBRAIC(:,230)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,448)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,479) = (ALGEBRAIC(:,477) - ALGEBRAIC(:,381)) - ALGEBRAIC(:,449);
    ALGEBRAIC(:,171) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,360) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,368) =  CONSTANTS(:,140).*(exp(ALGEBRAIC(:,171)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,360)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,297) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,480) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,481) =  CONSTANTS(:,163).*(exp(ALGEBRAIC(:,297)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,480)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,482) = ((ALGEBRAIC(:,468) - ALGEBRAIC(:,481)) - ALGEBRAIC(:,368)) -  - ALGEBRAIC(:,445);
    ALGEBRAIC(:,187) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46))+ CONSTANTS(:,182).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,48) = CONSTANTS(:,264)+STATES(:,26);
    ALGEBRAIC(:,386) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,194).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,396) =  CONSTANTS(:,142).*(exp(ALGEBRAIC(:,187)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,386)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,483) = (ALGEBRAIC(:,481) - ALGEBRAIC(:,396)) -  - ALGEBRAIC(:,449);
    ALGEBRAIC(:,225) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,446) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,447) =  CONSTANTS(:,151).*(exp(ALGEBRAIC(:,225)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,446)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,302) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,484) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,485) =  CONSTANTS(:,164).*(exp(ALGEBRAIC(:,302)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,484)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,486) = ((ALGEBRAIC(:,471) - ALGEBRAIC(:,485))+ALGEBRAIC(:,356)) - ALGEBRAIC(:,447);
    ALGEBRAIC(:,236) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32))+ CONSTANTS(:,183).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,450) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,195).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,451) =  CONSTANTS(:,153).*(exp(ALGEBRAIC(:,236)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,450)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,487) = (ALGEBRAIC(:,485)+ALGEBRAIC(:,381)) - ALGEBRAIC(:,451);
    ALGEBRAIC(:,310) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44))+ CONSTANTS(:,184).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,488) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48))+ CONSTANTS(:,196).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,489) =  CONSTANTS(:,165).*(exp(ALGEBRAIC(:,310)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,488)./( CONSTANTS(:,199).*CONSTANTS(:,200))));
    ALGEBRAIC(:,490) = ((ALGEBRAIC(:,474) - ALGEBRAIC(:,489))+ALGEBRAIC(:,368)) -  - ALGEBRAIC(:,447);
    ALGEBRAIC(:,314) =  CONSTANTS(:,173).*CONSTANTS(:,201).*ALGEBRAIC(:,101);
    ALGEBRAIC(:,115) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,68).*ALGEBRAIC(:,18));
    ALGEBRAIC(:,122) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,44).*ALGEBRAIC(:,48));
    ALGEBRAIC(:,129) = ALGEBRAIC(:,115)+ CONSTANTS(:,173).*CONSTANTS(:,201).*ALGEBRAIC(:,101)+ALGEBRAIC(:,122);
    ALGEBRAIC(:,108) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,67).*ALGEBRAIC(:,17));
    ALGEBRAIC(:,319) = ALGEBRAIC(:,108)+ALGEBRAIC(:,122);
    ALGEBRAIC(:,491) = piecewise({ALGEBRAIC(:,314)==0.000000,  CONSTANTS(:,102).*(exp(ALGEBRAIC(:,129)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,319)./( CONSTANTS(:,199).*CONSTANTS(:,200)))) },  ((( CONSTANTS(:,102).*ALGEBRAIC(:,314))./( CONSTANTS(:,199).*CONSTANTS(:,200)))./(exp(ALGEBRAIC(:,314)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - 1.00000)).*(exp(ALGEBRAIC(:,129)./( CONSTANTS(:,199).*CONSTANTS(:,200))) - exp(ALGEBRAIC(:,319)./( CONSTANTS(:,199).*CONSTANTS(:,200)))));
    ALGEBRAIC(:,492) = ALGEBRAIC(:,491);
    ALGEBRAIC(:,493) =  - ALGEBRAIC(:,491);
    ALGEBRAIC(:,494) = (ALGEBRAIC(:,489)+ALGEBRAIC(:,396)) - (( - ALGEBRAIC(:,451)+ALGEBRAIC(:,491)) - ALGEBRAIC(:,491));
    ALGEBRAIC(:,495) =  CONSTANTS(:,201).*((((((((((((((  - CONSTANTS(:,173).*ALGEBRAIC(:,491)+ CONSTANTS(:,196).*ALGEBRAIC(:,453)) -  CONSTANTS(:,184).*ALGEBRAIC(:,453)+ CONSTANTS(:,196).*ALGEBRAIC(:,465)) -  CONSTANTS(:,184).*ALGEBRAIC(:,465)+ CONSTANTS(:,196).*ALGEBRAIC(:,459)) -  CONSTANTS(:,184).*ALGEBRAIC(:,459)+ CONSTANTS(:,196).*ALGEBRAIC(:,471)) -  CONSTANTS(:,184).*ALGEBRAIC(:,471)+ CONSTANTS(:,196).*ALGEBRAIC(:,485)) -  CONSTANTS(:,184).*ALGEBRAIC(:,485)+ CONSTANTS(:,194).*ALGEBRAIC(:,329)) -  CONSTANTS(:,182).*ALGEBRAIC(:,329)+ CONSTANTS(:,194).*ALGEBRAIC(:,356)) -  CONSTANTS(:,182).*ALGEBRAIC(:,356)+ CONSTANTS(:,195).*ALGEBRAIC(:,432)) -  CONSTANTS(:,183).*ALGEBRAIC(:,432)+ CONSTANTS(:,195).*ALGEBRAIC(:,445)) -  CONSTANTS(:,183).*ALGEBRAIC(:,445)+ CONSTANTS(:,195).*ALGEBRAIC(:,449)) -  CONSTANTS(:,183).*ALGEBRAIC(:,449)+ CONSTANTS(:,196).*ALGEBRAIC(:,477)) -  CONSTANTS(:,184).*ALGEBRAIC(:,477)+ CONSTANTS(:,194).*ALGEBRAIC(:,343)) -  CONSTANTS(:,182).*ALGEBRAIC(:,343)+ CONSTANTS(:,194).*ALGEBRAIC(:,381) -  CONSTANTS(:,182).*ALGEBRAIC(:,381)+ CONSTANTS(:,195).*ALGEBRAIC(:,409) -  CONSTANTS(:,183).*ALGEBRAIC(:,409)+ CONSTANTS(:,196).*ALGEBRAIC(:,456) -  CONSTANTS(:,184).*ALGEBRAIC(:,456)+ CONSTANTS(:,196).*ALGEBRAIC(:,468) -  CONSTANTS(:,184).*ALGEBRAIC(:,468)+ CONSTANTS(:,196).*ALGEBRAIC(:,462) -  CONSTANTS(:,184).*ALGEBRAIC(:,462)+ CONSTANTS(:,196).*ALGEBRAIC(:,474) -  CONSTANTS(:,184).*ALGEBRAIC(:,474)+ CONSTANTS(:,196).*ALGEBRAIC(:,489) -  CONSTANTS(:,184).*ALGEBRAIC(:,489)+ CONSTANTS(:,194).*ALGEBRAIC(:,336) -  CONSTANTS(:,182).*ALGEBRAIC(:,336)+ CONSTANTS(:,194).*ALGEBRAIC(:,368) -  CONSTANTS(:,182).*ALGEBRAIC(:,368)+ CONSTANTS(:,195).*ALGEBRAIC(:,422) -  CONSTANTS(:,183).*ALGEBRAIC(:,422)+ CONSTANTS(:,195).*ALGEBRAIC(:,439) -  CONSTANTS(:,183).*ALGEBRAIC(:,439)+ CONSTANTS(:,195).*ALGEBRAIC(:,447) -  CONSTANTS(:,183).*ALGEBRAIC(:,447)+ CONSTANTS(:,195).*ALGEBRAIC(:,451) -  CONSTANTS(:,183).*ALGEBRAIC(:,451)+ CONSTANTS(:,196).*ALGEBRAIC(:,481) -  CONSTANTS(:,184).*ALGEBRAIC(:,481)+ CONSTANTS(:,194).*ALGEBRAIC(:,349) -  CONSTANTS(:,182).*ALGEBRAIC(:,349)+ CONSTANTS(:,194).*ALGEBRAIC(:,396)) -  CONSTANTS(:,182).*ALGEBRAIC(:,396));
    ALGEBRAIC(:,3) =  CONSTANTS(:,185).*(STATES(:,88)+STATES(:,89)+STATES(:,90)+STATES(:,91)+STATES(:,92)+STATES(:,93));
    ALGEBRAIC(:,21) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,2).*ALGEBRAIC(:,19));
    ALGEBRAIC(:,23) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,7).*ALGEBRAIC(:,20));
    ALGEBRAIC(:,25) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,14).*ALGEBRAIC(:,22));
    ALGEBRAIC(:,27) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,20).*ALGEBRAIC(:,24));
    ALGEBRAIC(:,29) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,33).*ALGEBRAIC(:,26));
    ALGEBRAIC(:,31) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,36).*ALGEBRAIC(:,28));
    ALGEBRAIC(:,33) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,41).*ALGEBRAIC(:,30));
    ALGEBRAIC(:,35) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,43).*ALGEBRAIC(:,32));
    ALGEBRAIC(:,37) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,4).*ALGEBRAIC(:,34));
    ALGEBRAIC(:,39) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,9).*ALGEBRAIC(:,36));
    ALGEBRAIC(:,41) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,16).*ALGEBRAIC(:,38));
    ALGEBRAIC(:,43) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,22).*ALGEBRAIC(:,40));
    ALGEBRAIC(:,45) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,34).*ALGEBRAIC(:,42));
    ALGEBRAIC(:,47) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,37).*ALGEBRAIC(:,44));
    ALGEBRAIC(:,49) =  CONSTANTS(:,199).*CONSTANTS(:,200).*log( CONSTANTS(:,42).*ALGEBRAIC(:,46));
    ALGEBRAIC(:,100) = ALGEBRAIC(:,99)./CONSTANTS(:,202);
end

% Compute result of a piecewise function
function x = piecewise(cases, default)
    set = [0];
    for i = 1:2:length(cases)
        if (length(cases{i+1}) == 1)
            x(cases{i} & ~set,:) = cases{i+1};
        else
            x(cases{i} & ~set,:) = cases{i+1}(cases{i} & ~set);
        end
        set = set | cases{i};
        if(set), break, end
    end
    if (length(default) == 1)
        x(~set,:) = default;
    else
        x(~set,:) = default(~set);
    end
end

% Pad out or shorten strings to a set length
function strout = strpad(strin)
    req_length = 160;
    insize = size(strin,2);
    if insize > req_length
        strout = strin(1:req_length);
    else
        strout = [strin, blanks(req_length - insize)];
    end
end

